--
-- Return a string JSON listing that defines properties that we want to display
-- in our live charting view.
--
-- @file    json/chart.lua
-- @version 2.5
--
local base = _G

local state = {
  ['channel'] = {
    {
      ['key'] = 0,
      ['id'] = 'a',
      ['name'] = 'Accelerometer',
      ['name_compact'] = 'Accel',
      ['unit'] = '1 g',
      ['info'] = 'Standard acceleration due to gravity at Earth\'s surface, 1 g = 980.665 cm/s²',
      ['dim'] = 3
    },
    {
      ['key'] = 1,
      ['id'] = 'm',
      ['name'] = 'Magnetometer',
      ['name_compact'] = 'Mag',
      ['unit'] = '50 µT',
      ['info'] = 'Magnetic flux in microtesla, 100 µT = 1 Guass. The magnitude of Earth\'s magnetic field varies from 25 to 65 µT',
      ['dim'] = 3
    },
    {
      ['key'] = 2,
      ['id'] = 'g',
      ['name'] = 'Gyroscope',
      ['name_compact'] = 'Gyro',
      ['unit'] = '500 °/s',
      ['info'] = 'Angular velocity in degrees per second',
      ['dim'] = 3
    },
    {
      ['key'] = 3,
      ['id'] = 'lt',
      ['name'] = 'Position',
      ['name_compact'] = 'Pos',
      ['unit'] = '100 cm',
      ['info'] = 'Position in centimeters',
      ['dim'] = 3
    }
  },
  ['node'] = {},
  ['rate'] = {
    {['key'] = 1, ['id'] = '1', ['num_frame'] = 100, ['name'] = '1'},
    {['key'] = 5, ['id'] = '5', ['num_frame'] = 500, ['name'] = '5'},
    {['key'] = 10, ['id'] = '10', ['num_frame'] = 1000, ['name'] = '10'},
    {['key'] = 20, ['id'] = '20', ['num_frame'] = 2000, ['name'] = '20'},
    {['key'] = 30, ['id'] = '30', ['num_frame'] = 3000, ['name'] = '30'}
  },
  ['time_step'] = 0.01
}

local _node_to_json
_node_to_json = function(configured_node)
  local state = {
    ['key'] = configured_node.key,
    ['id'] = configured_node.id,
    ['name'] = configured_node.name,
    ['active'] = (configured_node.active and not configured_node.bus)
  }

  return state
end

local list = node.configuration()
if list then
  local max_time_step = 0
  local item
  for _,item in pairs(list:list()) do
    local node_state = _node_to_json(item)
    if node_state then -- and node_state.active then
      table.insert(state.node, node_state)
    end

    if item.time_step > max_time_step then
      max_time_step = item.time_step
    end
  end

  if not(state.time_step == max_time_step) then
    for _,item in pairs(state.rate) do
      item.num_frame = math.floor(
        item.num_frame * (state.time_step / max_time_step) + 0.5)
    end
    state.time_step = max_time_step
  end
end

return node.json.encode(state)
