--
-- Return a string JSON description of the current configuration list of the
-- Motion Service. Show all hardware devices that are available and their
-- current status.
--
-- @file    json/devices.lua
-- @version 2.5
--
local base = _G

local is_taking = node.is_taking()
local is_reading = is_taking or node.is_reading()
local is_connected = is_reading or node.is_connected()
local is_configured = is_connected or node.is_configured()
local is_tracking = node.is_tracking()

local state = {
  ['is_configured'] = is_configured,
  ['is_connected'] = is_connected,
  ['is_reading'] = is_reading,
  ['is_taking'] = is_taking,
  ['is_tracking'] = is_tracking,
  ['node'] = {}
}

local _node_to_json
_node_to_json = function(item, default_node, is_connected, is_reading, detail)
  local show_detail = false
  if detail and item.id == detail then
    show_detail = true
  end

  local state = {
    ['key'] = item.key,
    ['id'] = item.id,
    ['name'] = item.name,
    ['source'] = item.source,
    ['gain'] = item.gain,
    ['gain_sensor'] = item.gain_sensor,
    ['gselect'] = item.gselect,
    ['time_step'] = item.time_step,
    --['gain_sensor'] = item.gain_sensor,
    ['track_gyroscope_bias'] = item.track_gyroscope_bias,
    ['pipeline_select'] = item.pipeline_select,
    ['auth'] = item.auth,
    ['is_connected'] = is_connected or node.is_connected(item.id),
    ['is_reading'] = is_reading or node.is_reading(item.id),
    ['node'] = {}
  }

  local optional = {
    'active',
    --'auth',
    'bus',
    'delay',
    'flags',
    --'gain',
    --'gain_sensor',
    'node_version',
    'parent',
    'pipeline_select',
    'sample_rate',
    --'time_step',
    --'track_gyroscope_bias',
    'uuid'
  }

  for _,field in pairs(optional) do
    if show_detail or item[field] ~= default_node[field] then
      state[field] = item[field]
    end
  end

  return state
end

local _tree_to_json
_tree_to_json = function(item, default_node, is_connected, is_reading, detail)
  local result = _node_to_json(
    item.value, default_node, is_connected, is_reading, detail)

  local child_node
  for _,child_node in pairs(item:list()) do
    table.insert(
      result.node,
      _tree_to_json(child_node, default_node, is_connected, is_reading, detail))
  end

  return result
end

if true then
  --
  -- Node list.
  --
  local node_list = node.configuration()
  if node_list then
    local default_node = node.get_node_default()
    local item
    for _,item in pairs(node_list:list()) do
      local item_state = _node_to_json(
        item, default_node, is_connected, is_reading, node_detail)
      if item_state then
        table.insert(state.node, item_state)
      end
    end
  end
else
  --
  -- Node tree.
  --
  local node_list = node.configuration_tree()
  if node_list then
    local default_node = node.get_node_default()
    local item
    for _,item in pairs(node_list:list()) do
      local item_state = _tree_to_json(
        item, default_node, is_connected, is_reading, node_detail)
      if item_state then
        table.insert(state.node, item_state)
      end
    end
  end
end


return node.json.encode(state)
