--
-- Return a string JSON description of the current geographic location of the
-- Motion Service. Same format as the online geocoder at:
--
--   https://www.motionnode.com/geocode/
--
-- @file    json/location.lua
-- @version 2.5
--

-- Utility function. Generate a location Json object based on parameters.
local _location_to_json
_location_to_json = function(location)
  local result = {
    ['name'] = location.name,
    ['address'] = location.address,
    ['point'] = {
      ['latitude'] = location.latitude,
      ['longitude'] = location.longitude,
      ['elevation'] = location.elevation
    },
    ['key'] = location.key,
    ['active'] = (location.active > 0)
  }

  return result
end

local location_table = {}

local list = node.system.get_location_list()
if list then
  for _,location in ipairs(list:list()) do
    table.insert(location_table, _location_to_json(location))
  end

  table.sort(location_table, function(a, b)
    return (a.name < b.name)
  end)
else
  local preference = node.system.get_preference()
  if preference then
    table.insert(location_table, _location_to_json(preference.location))
  end
end

return node.json.encode({
  ['geocode'] = {
    ['location'] = location_table
  }
})
