--
-- Return a string JSON listing of the available UI views. Order them how we
-- want them presented and put them into related groups.
--
-- @file    json/views.lua
-- @version 2.5
--
local base = _G
local group = {}

if node.system.is_initialized() then
  local show_shadow = 1
  local show_motion = 0

  local shadow = node.system.get_default('_shadow')
  if '' == shadow or not base.tonumber(shadow) then
    show_shadow = 0
    show_motion = 1
  end

  table.insert(group, {
    {['name'] = 'viewer', ['title'] = '3D Viewer', ['icon'] = '3d_rotation', ['show'] = show_shadow},
    {['name'] = 'node', ['title'] = 'Node Viewer', ['icon'] = '3d_rotation', ['show'] = show_motion},
    {['name'] = 'devices', ['title'] = 'Devices', ['icon'] = 'device_hub'},
    {['name'] ='chart', ['title'] = 'Chart', ['icon'] = 'show_chart'}
  })

  table.insert(group, {
    {['name'] = 'location', ['title'] = 'Location', ['icon'] = 'near_me'},
    {['name'] = 'log', ['title'] = 'Log', ['icon'] = 'list'},
    {['name'] = 'console', ['title'] = 'Console', ['icon'] = 'code'},
  })

  table.insert(group, {
    {['name'] = 'settings', ['title'] = 'Settings', ['icon'] = 'settings'},
    {['name'] = 'help', ['title'] = 'Help', ['icon'] = 'help'},
    {['name'] = 'calibrate', ['title'] = 'Calibrate', ['icon'] = 'builder', ['show'] = 0},
    {['name'] = 'error', ['title'] = 'Error', ['icon'] = 'error', ['show'] = 0}
  })
else
  table.insert(group, {
    {['name'] = 'setup', ['title'] = 'Setup', ['icon'] = 'settings applications', ['show'] = 1},
    {['name'] = 'log', ['title'] = 'Log', ['icon'] = 'list'}
  })
end

return node.json.encode({['views'] = group})
