--
-- Return an string XML description of the current geographic location of the
-- Motion Service. Same format as the online geocoder at:
--   http://www.motionnode.com/geocode/
--
-- @file    static/location.lua
-- @version 2.0
--

-- Utility function. Generate a location XML snippet based on input parameters.
local function location_node_to_xml(location)
  local result =
    "<location key=\"" .. node.xml.encode_attribute(location.key) ..
    "\" active=\"" .. node.xml.encode_attribute(location.active) .. "\">" ..
    "<name>" .. node.xml.encode_string(location.name) .. "</name>" ..
    "<address>" .. node.xml.encode_string(location.address) .. "</address>" ..
    "<point>" ..
    "<latitude>" .. node.xml.encode_string(location.latitude) .. "</latitude>" ..
    "<longitude>" .. node.xml.encode_string(location.longitude) .. "</longitude>" ..
    "<elevation unit=\"meter\">" .. node.xml.encode_string(location.elevation) .. "</elevation>" ..
    "</point>" ..
    "</location>"

  return result
end

local result =
  "<?xml version=\"1.0\"?>" ..
  "<geocode>"

local location_list = node.system.get_location_list()
if location_list then
  for _,location in ipairs(location_list:list()) do
    result = result .. location_node_to_xml(location)
  end
else
  local preference = node.system.get_preference()
  if preference then
    result = result .. location_node_to_xml(preference.location)
  end
end

result = result .. "</geocode>"

return result
