<?xml version="1.0"?>
<!--
  Create an HTML version of the MotionNode take file
  format.

  @file    static/style/boost_serialization.xsl
  @author  Luke Tokheim, luke@motionnode.com
  @version 2.0
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:import href="common.xsl"/>
 <xsl:template name="Title">
  <xsl:call-template name="kTake"/>
 </xsl:template>

 <xsl:template name="JavascriptShortcut">
  <xsl:text>[</xsl:text>
  <xsl:text>{command:'open', name:'Load take', active:true, key: 'l', argument: this_uri()}</xsl:text>
  <xsl:text>,{command:'load_take_source', name:'Load take source', active:true, key: 's', argument: this_uri()}</xsl:text>
  <xsl:text>]</xsl:text>
 </xsl:template>
 
 <xsl:template match="boost_serialization">
  <xsl:apply-templates select="take"/>
 </xsl:template>
 
 <xsl:template match="take">
  <div id="take">
   <h1>
    <xsl:call-template name="Title"/>
   </h1>
   <table>
    <tr>
     <th>Name</th>
     <td>
      <xsl:value-of select="name"/>
     </td>
    </tr>
    <tr>
     <th>Description</th>
     <td>
      <xsl:value-of select="description"/>
     </td>
    </tr>
    <tr>
     <th>Start time</th>
     <td>
      <xsl:apply-templates select="start/iso_extended"/>
     </td>
    </tr>
    <tr>
     <th>End time</th>
     <td>
      <xsl:apply-templates select="end/iso_extended"/>
     </td>
    </tr>
    <tr>
     <th>Location</th>
     <td>
      <xsl:apply-templates select="location/item"/>
     </td>
    </tr>
    <tr>
     <th>Geomagnetic</th>
     <td>
      <xsl:apply-templates select="geomagnetic/item"/>
     </td>
    </tr> 
    <tr>
     <th>Configuration</th>
     <td>
      <xsl:element name="a">
       <xsl:attribute name="title">
        <xsl:text>View configuration file associated with this take.</xsl:text>
       </xsl:attribute>
       <xsl:attribute name="href">
        <xsl:value-of select="configuration_path"/>
       </xsl:attribute>
       <xsl:value-of select="configuration_path"/>
      </xsl:element>
     </td>
    </tr>
    <tr>
     <th>Channel list</th>
     <td>
      <xsl:apply-templates select="channel_list"/>
     </td>
    </tr>
   </table>

   <div>
    <xsl:call-template name="command_anchor">
     <xsl:with-param name="text">Load take</xsl:with-param>
     <xsl:with-param name="command">open</xsl:with-param>
     <xsl:with-param name="argument">this_uri()</xsl:with-param>
     <xsl:with-param name="help">Load this as the current take to export data.</xsl:with-param>
     <xsl:with-param name="accesskey">l</xsl:with-param>
    </xsl:call-template>
    <xsl:text> , </xsl:text>
    <xsl:call-template name="command_anchor">
     <xsl:with-param name="text">Load take source</xsl:with-param>
     <xsl:with-param name="command">load_take_source</xsl:with-param>
     <xsl:with-param name="argument">this_uri()</xsl:with-param>
     <xsl:with-param name="help">Load this take as the current configuration source to replay.</xsl:with-param>
     <xsl:with-param name="accesskey">s</xsl:with-param>
    </xsl:call-template>
   </div>
  </div>

 </xsl:template>

 <xsl:template match="iso_extended">
  <xsl:call-template name="format_iso_extended">
   <xsl:with-param name="value">
    <xsl:apply-templates/>
   </xsl:with-param>
  </xsl:call-template>
 </xsl:template>

 <xsl:template match="take/channel_list">
  <div id="configuration">
   <table>
    <thead>
     <tr>
      <th>Id</th>
      <th>Name</th>
      <th>Source</th>
     </tr>
    </thead>
    <tbody>
      <xsl:apply-templates select="item/second"/>
    </tbody>
   </table>
  </div>
 </xsl:template> 

 <xsl:template match="take/channel_list/item/second">
  <tr>
   <td>
    <xsl:value-of select="id"/>
   </td>
   <td>
    <xsl:value-of select="name"/>
   </td>
   <td>
    <xsl:value-of select="source"/>
   </td>
  </tr>
 </xsl:template>
 
 <!-- Override default rules for real valued numbers. Use a common output format.  -->
 <xsl:template match="location/item|geomagnetic/item">
  <span class="item">
   <xsl:value-of select="format-number(text(),'0.##')"/>
  </span>
 </xsl:template> 
 
</xsl:stylesheet>