<?xml version="1.0"?>
<!--
  Common stylesheet for all HTML output. Implements the shared basic HTML
  wrapper for the web browser based user interface.

  @file    static/style/common.xsl
  @author  Luke Tokheim, luke@motionnode.com
  @version 2.4
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <!--
  String constants supporting i10n. By convention, these are prefixed with the
  'k' character, <xsl:call-template name="k..."/>.
 -->
 <xsl:import href="strings.xsl"/>
 <!-- Localized versions of the string constants. -->
 <xsl:import href="local.xsl"/>
 <!-- User interface optional branding. -->
 <xsl:import href="brand.xsl"/>
 <xsl:output
  method="html"
  indent="yes"
  doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
  doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>

 <!-- Strip all whitespace. -->
 <xsl:strip-space elements="*"/> 

 <!-- Constant variable definitions. -->
 <xsl:variable name="True">
  <xsl:text>true</xsl:text>
 </xsl:variable>
 <xsl:variable name="False">
  <xsl:text>false</xsl:text>
 </xsl:variable>
 <xsl:variable name="Name">
  <xsl:text>Node</xsl:text>
 </xsl:variable>
 <xsl:variable name="BaseURL">
  <xsl:text>/v1/</xsl:text>
 </xsl:variable>
 <xsl:variable name="BaseDataURL">
  <xsl:text>/</xsl:text>
 </xsl:variable>

 <!-- Forward declaration of any template "variables" this stylesheet uses. -->
 <xsl:template name="BaseTitle">
  <xsl:choose>
   <xsl:when test="/*[@version_shadow]">
    <xsl:call-template name="kShadow"/>
    <xsl:if test="/*[@version_bus]">
     <xsl:text> </xsl:text>
     <xsl:call-template name="kBus"/>
    </xsl:if>      
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="kMotion"/>
    <xsl:if test="/*[@version_bus]">
     <xsl:text> </xsl:text>
     <xsl:call-template name="kBus"/>
    </xsl:if>     
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>
 <xsl:template name="Version">
  <xsl:choose>
   <xsl:when test="/*[@version]">
    <xsl:value-of select="/*[@version]/@version"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="kVersion"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>
 <xsl:template name="Title"/>
 <xsl:template name="Monitor">
  <xsl:text>0</xsl:text>
 </xsl:template>
 <xsl:template name="LoadState">
  <xsl:value-of select="$True"/>
 </xsl:template>
 <xsl:template name="JavascriptShortcut">
  <xsl:text>[]</xsl:text>
 </xsl:template>
 <xsl:template name="CloseShortcut">
  <xsl:choose>
   <xsl:when test="count(/state//node[@connected=$True])&gt;0 and @connected=$False">
    <xsl:text>L</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>C,L</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>
 <xsl:template name="JavascriptHead"/>
 <xsl:template name="SetDateTime">
  <xsl:choose>
   <xsl:when test="/*[@version_bus]">
    <xsl:text>true</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>false</xsl:text>
   </xsl:otherwise>  
  </xsl:choose>
 </xsl:template>
 <xsl:template name="FileUpload">
  <xsl:text>0</xsl:text>
 </xsl:template>
 <xsl:template name="ConfigurationFile">
  <xsl:text>configuration.mNode</xsl:text>
 </xsl:template>
 <xsl:template name="GSelect">
  <xsl:text>2</xsl:text>
 </xsl:template> 
 <xsl:template name="SampleRate">
  <xsl:text>100</xsl:text>
 </xsl:template>
 <xsl:template name="TakeFile">
  <xsl:text>take</xsl:text>
  <xsl:choose>
   <xsl:when test="/*[@version_bus or not(@version_shadow)]">
    <xsl:text>.csv</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>.fbx</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>
 <xsl:template name="ExportStreamFile">
  <xsl:text>take_stream.csv</xsl:text>
 </xsl:template>
 <xsl:template name="ViewerPath">
  <xsl:value-of select="$BaseURL"/>
  <xsl:choose>
   <xsl:when test="/*[@tracking=$True or @version_shadow]">
    <xsl:text>app/</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>viewer.html</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>
 <xsl:variable name="FileUpload">
  <xsl:call-template name="FileUpload"/>
 </xsl:variable>
 <xsl:variable name="ShowTrack">
  <xsl:if test="/*[@tracking=$True] or count(//node/node/node) &gt; 0">
   <xsl:text>1</xsl:text>
  </xsl:if>
 </xsl:variable>
 
 <!-- Default rule. Squash any nodes without explicit rules. -->
 <xsl:template match="*"/>

 <!-- Root rule. Create the common HTML wrapper. -->
 <xsl:template match="/">
  <xsl:element name="html">
   <xsl:attribute name="lang">
    <xsl:call-template name="kLanguage"/>
   </xsl:attribute>
   <xsl:element name="head">
    <xsl:element name="title">
     <xsl:call-template name="BaseTitle"/>
     <xsl:text>: </xsl:text>
     <xsl:call-template name="Title"/>
    </xsl:element>
    <link rel="stylesheet" type="text/css" href="{$BaseURL}style/common.css" media="screen"/>
    <xsl:call-template name="BrandCSS"/>
    <link rel="shortcut icon" href="{$BaseURL}image/favicon.ico" type="image/x-icon"/>
    <script type="text/javascript" src="{$BaseURL}javascript/lib.js"></script>
    <script type="text/javascript">
     <xsl:text>//&lt;![CDATA[
</xsl:text>
     <xsl:call-template name="JavascriptHead"/>
     <xsl:text>
//]]&gt;</xsl:text>
    </script>
    <xsl:if test="$FileUpload">
     <script type="text/javascript" src="{$BaseURL}m/js/jquery.js"></script>
     <script type="text/javascript" src="{$BaseURL}m/js/upload.js"></script>
    </xsl:if>
   </xsl:element>
   <xsl:element name="body">
    <xsl:attribute name="onload">
     <xsl:text>return init(</xsl:text>
     <xsl:call-template name="Monitor"/>,
     <xsl:call-template name="LoadState"/>,
     <xsl:call-template name="JavascriptShortcut"/>,
     <xsl:call-template name="SetDateTime"/>
     <xsl:text>);</xsl:text>
    </xsl:attribute>
    <xsl:element name="noscript">
     <div style="margin: 1em; padding-left: 1em; padding-right: 1em; border: 1px solid navy;">
      <p><xsl:call-template name="kJavaScriptRequired"/></p>
     </div>
    </xsl:element>
    <div class="header">
     <xsl:call-template name="BrandHeader"/>
    </div>
    <div class="content">
     <xsl:apply-templates/>
     <div id="command_accesskey"></div> 
    </div>
    <div class="footer">
     <xsl:element name="a">
      <xsl:attribute name="href">
        <xsl:value-of select="$BaseURL"/>
      </xsl:attribute>
      <xsl:attribute name="title">
       <xsl:call-template name="kReturnToStatus"/>
      </xsl:attribute>
      <xsl:call-template name="BaseTitle"/>
     </xsl:element>
     <xsl:text> </xsl:text>
     <xsl:call-template name="Version"/>
    </div>
    <div id="notify_frame">
     <span id="notify">
     </span>
    </div>
    <div id="edit"></div>
    <div id="menu"></div>
   </xsl:element>
  </xsl:element>
 </xsl:template>

 <!-- Shared template to generate an RPC anchor tag. -->
 <xsl:template name="command_anchor">
  <xsl:param name="argument"/>
  <xsl:param name="command"/>
  <xsl:param name="text"/>
  <xsl:param name="accesskey"/>
  <xsl:param name="help"/>

  <xsl:element name="a">
   <xsl:if test="string-length($accesskey)&gt;0">
    <xsl:attribute name="accesskey">
     <xsl:value-of select="substring($accesskey,1,1)"/>
    </xsl:attribute>
   </xsl:if>
   <xsl:attribute name="href">
    <xsl:text>javascript:GLI_Command.send('</xsl:text>
    <xsl:value-of select="$command"/>
    <xsl:text>'</xsl:text>
    <xsl:if test="string-length($argument)&gt;0">
     <xsl:text>,</xsl:text>
     <xsl:value-of select="$argument"/>
    </xsl:if>
    <xsl:text>)</xsl:text>
   </xsl:attribute>
   <xsl:attribute name="class">
    <xsl:text>send_command</xsl:text>
   </xsl:attribute>
   <xsl:if test="string-length($help)&gt;0">
    <xsl:attribute name="title">
     <xsl:value-of select="$help"/>
    </xsl:attribute>
   </xsl:if>
   <xsl:value-of select="$text"/>
  </xsl:element>
 </xsl:template>

 <!-- Shared template to generate an editable field. -->
 <xsl:template name="edit_element">
  <xsl:param name="id"/>
  <xsl:param name="key"/>
  <xsl:param name="command"/>
  <xsl:param name="text"/>
  <xsl:param name="class">edit_string</xsl:param>
  <xsl:param name="select"/>
  <xsl:param name="select_key"/>
  <xsl:param name="element">td</xsl:param>

  <xsl:element name="{$element}">
   <xsl:attribute name="title">
    <xsl:call-template name="kClickToEdit"/>
   </xsl:attribute>
   <xsl:attribute name="onmouseout">
    <xsl:text>this.style.borderColor='#fff'</xsl:text>
   </xsl:attribute>
   <xsl:attribute name="onmouseover">
    <xsl:text>this.style.borderColor='rgb(88%,90%,92%)'</xsl:text>
   </xsl:attribute>
   <xsl:attribute name="onclick">
    <xsl:text>javascript:GLI_Edit.open(this,'</xsl:text>
    <xsl:value-of select="$command"/>
    <xsl:choose>
     <xsl:when test="string-length($id)&gt;0">
      <xsl:text>','</xsl:text>
      <xsl:value-of select="$id"/>
      <xsl:text>'</xsl:text>
     </xsl:when>
     <xsl:otherwise>
      <xsl:text>',null</xsl:text>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:if test="string-length($select)&gt;0">
     <xsl:text>,</xsl:text>
     <xsl:value-of select="$select"/>
    </xsl:if>
    <xsl:if test="string-length($select_key)&gt;0">
     <xsl:text>,</xsl:text>
     <xsl:value-of select="$select_key"/>
    </xsl:if> 
    <xsl:text>)</xsl:text>
   </xsl:attribute>
   <xsl:attribute name="class">
    <xsl:value-of select="$class"/>
   </xsl:attribute>
   <xsl:attribute name="id">
    <xsl:if test="string-length($id)&gt;0">
     <xsl:value-of select="$id"/>
     <xsl:text>.</xsl:text>
    </xsl:if>
    <xsl:value-of select="$command"/>
   </xsl:attribute>
   <xsl:value-of select="$text"/>
  </xsl:element>
 </xsl:template>

 <!-- Shared template to generate a drop down menu button. -->
 <xsl:template name="menu_button">
  <xsl:param name="menu"/>
  <xsl:param name="text"/>
  <xsl:param name="help"/>
  <xsl:param name="inactive"/>
  <xsl:param name="class">
   <xsl:text>button</xsl:text>
  </xsl:param>

  <xsl:element name="td">
   <xsl:if test="string-length($help)&gt;0">
    <xsl:attribute name="title">
     <xsl:value-of select="$help"/>
    </xsl:attribute>
   </xsl:if>
   <xsl:element name="div">
    <xsl:if test="$inactive=$True">
     <xsl:attribute name="style">
      <xsl:text>color: #676767;</xsl:text>
     </xsl:attribute>
    </xsl:if>
    <xsl:attribute name="onmouseout">
     <xsl:text>this.style.backgroundColor='#fff'</xsl:text>
    </xsl:attribute>
    <xsl:attribute name="onmouseup">
     <xsl:text>this.style.backgroundColor='#fff'</xsl:text>
    </xsl:attribute>
    <xsl:attribute name="onmousedown">
     <xsl:text>this.style.backgroundColor='rgb(88%,90%,92%)'</xsl:text>
    </xsl:attribute>
    <xsl:attribute name="onclick">
     <xsl:text>GLI_Menu.open(event,this,</xsl:text>
     <xsl:value-of select="$menu"/>
     <xsl:text>)</xsl:text>
    </xsl:attribute>
    <xsl:attribute name="class">
     <xsl:value-of select="$class"/>
    </xsl:attribute>
    <xsl:value-of select="$text"/>
    <xsl:text> </xsl:text>
    <xsl:call-template name="menu_dropdown_img"/>
   </xsl:element>
  </xsl:element>
 </xsl:template>

 <xsl:template name="menu_dropdown_img">
  <xsl:element name="img">
   <xsl:attribute name="src">
    <xsl:value-of select="$BaseURL"/>
    <xsl:text>image/menu_dropdown.png</xsl:text>
   </xsl:attribute>
   <xsl:attribute name="alt">
    <xsl:text>Menu Dropdown</xsl:text>
   </xsl:attribute>
   <xsl:attribute name="width">
    <xsl:text>8</xsl:text>
   </xsl:attribute>
   <xsl:attribute name="height">
    <xsl:text>6</xsl:text>
   </xsl:attribute>
  </xsl:element>
 </xsl:template>

 <xsl:template name="make_menubar">
  <xsl:param name="MenuFile"/>
  <xsl:param name="MenuNode"/>
  <xsl:param name="MenuBus"/>
  <xsl:param name="LinkLocation">
   <xsl:value-of select="$True"/>
  </xsl:param>
  
  <xsl:element name="table">
   <xsl:attribute name="id">
    <xsl:text>menubar</xsl:text>
   </xsl:attribute>
   <xsl:element name="tr">
    <xsl:call-template name="menu_button">
     <xsl:with-param name="menu">
      <xsl:value-of select="$MenuFile"/>
     </xsl:with-param>
     <xsl:with-param name="text">
      <xsl:call-template name="kFile"/>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:element name="td"/>
    <xsl:call-template name="menu_button">
     <xsl:with-param name="menu">
      <xsl:value-of select="$MenuNode"/>
     </xsl:with-param>
     <xsl:with-param name="text">
      <xsl:call-template name="kNode"/>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:if test="string-length($MenuBus)&gt;0">
     <xsl:element name="td"/>
     <xsl:call-template name="menu_button">
      <xsl:with-param name="menu">
       <xsl:value-of select="$MenuBus"/>
      </xsl:with-param>
      <xsl:with-param name="text">
       <xsl:call-template name="kBus"/>
      </xsl:with-param>
     </xsl:call-template>
    </xsl:if>

    <xsl:element name="td">
     <xsl:element name="div">
      <xsl:attribute name="class">
       <xsl:text>button</xsl:text>
      </xsl:attribute>
      <xsl:attribute name="style">margin-left: 1em; border: 1px solid #fff;</xsl:attribute>
      <xsl:attribute name="onmouseout">
       <xsl:text>this.style.borderColor='#fff'</xsl:text>
      </xsl:attribute>
      <xsl:attribute name="onmouseover">
       <xsl:text>this.style.borderColor='rgb(88%,90%,92%)'</xsl:text>
      </xsl:attribute>
      <xsl:attribute name="onclick">
       <xsl:text>GLI_Menu.open(event,this,</xsl:text>
       <xsl:text>[</xsl:text>
       <xsl:text>{href:'location.lua',name:'</xsl:text>
       <xsl:call-template name="kLocation"/>
       <xsl:text>',title:'</xsl:text>
       <xsl:call-template name="kLocationTitle"/>
       <xsl:text>'},</xsl:text>
       <xsl:if test="/*[not(@version_bus) and @version_shadow]">
        <xsl:text>{href:'ractor.lua',name:'</xsl:text>
        <xsl:call-template name="kRactor"/>
        <xsl:text>',title:'</xsl:text>
        <xsl:call-template name="kRactorTitle"/>
        <xsl:text>'},</xsl:text>
       </xsl:if>
       <xsl:if test="string-length(log_path/text())">
        <xsl:text>{},{href:'/</xsl:text>
        <xsl:apply-templates select="log_path/text()"/>
        <xsl:text>',name:'</xsl:text>
        <xsl:call-template name="kLog"/>
        <xsl:text>',title:'</xsl:text>
        <xsl:call-template name="kLogTitle"/>
        <xsl:text>'},</xsl:text>        
       </xsl:if>
       <xsl:text>{},{href:'console.xml',name:'</xsl:text>
       <xsl:call-template name="kConsole"/>
       <xsl:text>',title:'</xsl:text>
       <xsl:call-template name="kConsoleTitle"/>
       <xsl:text>'},</xsl:text>
       <xsl:text>{href:'?detail=default',name:'</xsl:text>
       <xsl:call-template name="kDefaults"/>
       <xsl:text>',title:'</xsl:text>
       <xsl:call-template name="kDefaultsTitle"/>
       <xsl:text>'},</xsl:text>
       <xsl:text>{},{href:'javascript:toggle_mobile();',name:'</xsl:text>
       <xsl:call-template name="kMobile"/>
       <xsl:text>',title:'</xsl:text>
       <xsl:call-template name="kMobileTitle"/>
       <xsl:text>'},</xsl:text>
       <xsl:text>{},{href:'</xsl:text>
       <xsl:call-template name="kHelpURL"/>
       <xsl:text>',name:'</xsl:text>
       <xsl:call-template name="kHelp"/>
       <xsl:text>',title:'</xsl:text>
       <xsl:call-template name="kHelpTitle"/>
       <xsl:text>'}</xsl:text>
       <xsl:text>]</xsl:text>
       <xsl:text>,null,true)</xsl:text>
      </xsl:attribute>
      <xsl:element name="a">
       <xsl:attribute name="title">
        <xsl:call-template name="kViewerTitle"/>
       </xsl:attribute>
       <xsl:attribute name="href">
        <xsl:call-template name="ViewerPath"/>
       </xsl:attribute>
       <xsl:attribute name="onclick">
        <xsl:text>GLI_EventListener.stop(event);</xsl:text>
       </xsl:attribute>
       <xsl:call-template name="kViewer"/>
      </xsl:element>
      <xsl:text> </xsl:text>
      <xsl:element name="span">
       <xsl:attribute name="style">margin-left: 8px; margin-right: 4px;</xsl:attribute>
       <xsl:call-template name="menu_dropdown_img"/>
      </xsl:element>
     </xsl:element>
    </xsl:element>

    <xsl:element name="td">
     <xsl:element name="div">
      <xsl:choose>
       <xsl:when test="count(/*/take)&gt;0">
        <xsl:attribute name="class">
         <xsl:text>button</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="style">margin-left: 1em; border: 1px solid #fff; font-size: 100%;</xsl:attribute>
        
        <xsl:attribute name="onclick">
         <xsl:text>GLI_Menu.open(event,this,</xsl:text>
         <xsl:text>[</xsl:text>
         <xsl:text>{href:'/take/',name:'</xsl:text>
         <xsl:call-template name="kBrowseTake"/>
         <xsl:text>',title:'</xsl:text>
         <xsl:call-template name="kBrowseTakeTitle"/>
         <xsl:text>'},</xsl:text>
         <xsl:text>]</xsl:text>
         <xsl:text>,null,true)</xsl:text>
        </xsl:attribute>

        <xsl:apply-templates select="take"/>
        <xsl:element name="span">
         <xsl:attribute name="style">margin-left: 8px; margin-right: 4px;</xsl:attribute>
         <xsl:call-template name="menu_dropdown_img"/>
        </xsl:element> 
       </xsl:when>
       
       <xsl:otherwise>
        <xsl:attribute name="style">margin-left: 1em;</xsl:attribute>
        <xsl:element name="span">
         <xsl:attribute name="style">
          <xsl:text>font-style: italic; color: #676767;</xsl:text>
         </xsl:attribute>
         <xsl:choose>
          <xsl:when test="/state/@taking=$True">
           <xsl:call-template name="kTakeInProgress"/>
          </xsl:when>
          <xsl:otherwise>
           <xsl:element name="a">
            <xsl:attribute name="title">
             <xsl:call-template name="kEmptyTakeTitle"/>
            </xsl:attribute>
            <xsl:attribute name="style">
             <xsl:text>color: #676767;</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="href">
             <xsl:text>/take/</xsl:text>
            </xsl:attribute>
            <xsl:call-template name="kEmptyTake"/>
           </xsl:element>
          </xsl:otherwise>
         </xsl:choose>
        </xsl:element>
       </xsl:otherwise>
       
      </xsl:choose>
     </xsl:element>
    </xsl:element>

   </xsl:element>
  </xsl:element>
 </xsl:template>
 
 <!-- Shared template format ISO Extended timestamp. 2006-07-20T12:59:30.484375Z  -->
 <xsl:template name="format_iso_extended">
  <xsl:param name="value"/>

  <xsl:variable name="before">
   <xsl:choose>
    <xsl:when test="contains($value,'.')">
     <xsl:text>.</xsl:text>
    </xsl:when>
    <xsl:otherwise>
     <xsl:text>Z</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>

  <xsl:value-of select="translate(substring-before($value,$before),'T',' ')"/>
 </xsl:template>

 <!-- Shared template to generate the Node command menu. -->
 <xsl:template name="node_to_menu">
  <xsl:variable name="is_root_menu">
   <xsl:value-of select="count(ancestor::*)=0"/>
  </xsl:variable>
  <xsl:variable name="node1_gselect">
   <xsl:choose>
    <xsl:when test="string-length(/state//node[position()=1 and @gselect]/@gselect)">
     <xsl:value-of select="/state//node[position()=1 and @gselect]/@gselect"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:text>2</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:variable name="node_gselect">
   <xsl:choose>
    <xsl:when test="$is_root_menu=$True">
     <xsl:choose>
      <xsl:when test="count(/state//node[@gselect != $node1_gselect])=0">
       <xsl:value-of select="$node1_gselect"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="GSelect"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:when>
    <xsl:otherwise>
     <xsl:choose>
      <xsl:when test="string-length(@gselect)">
       <xsl:value-of select="@gselect"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="GSelect"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:variable name="node1_sample_rate">
   <xsl:choose>
    <xsl:when test="string-length(/state//node[position()=1 and @sample_rate]/@sample_rate)">
     <xsl:value-of select="/state//node[position()=1 and @sample_rate]/@sample_rate"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:call-template name="SampleRate"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:variable name="node_sample_rate">
   <xsl:choose>
    <xsl:when test="$is_root_menu=$True">
     <xsl:choose>
      <xsl:when test="count(/state//node[@sample_rate != $node1_sample_rate])=0">
       <xsl:value-of select="$node1_sample_rate"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="SampleRate"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:when>
    <xsl:otherwise>
     <xsl:choose>
      <xsl:when test="string-length(@sample_rate)">
       <xsl:value-of select="@sample_rate"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="SampleRate"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:otherwise> 
   </xsl:choose>
  </xsl:variable>

  <xsl:text>[</xsl:text>
  <xsl:if test="$is_root_menu=$True">
   <xsl:call-template name="make_menu_command">
    <xsl:with-param name="command">start_take</xsl:with-param>
    <xsl:with-param name="name">
     <xsl:call-template name="kStartTake"/>
    </xsl:with-param>
    <xsl:with-param name="help">
     <xsl:call-template name="kStartTakeTitle"/>
    </xsl:with-param>
    <xsl:with-param name="help_inactive">
     <xsl:if test="@taking=$True">
      <xsl:call-template name="kStartTakeInfo"/>
     </xsl:if>
     <xsl:if test="@configured=$False">
      <xsl:call-template name="kRequiresConfiguration"/>
     </xsl:if>
    </xsl:with-param>
    <xsl:with-param name="active"
                    select="@taking=$False and @configured=$True"/>
    <xsl:with-param name="key">T</xsl:with-param>
   </xsl:call-template>
   <xsl:text>,</xsl:text>
  </xsl:if>
  <xsl:call-template name="make_menu_command">
   <xsl:with-param name="command">start</xsl:with-param>
   <xsl:with-param name="name">
    <xsl:call-template name="kStartReading"/>
   </xsl:with-param>
   <xsl:with-param name="help">
    <xsl:call-template name="kStartReadingTitle"/>
   </xsl:with-param>
   <xsl:with-param name="help_inactive">
    <xsl:if test="@reading=$True">
     <xsl:call-template name="kStartReadingInfo"/>
    </xsl:if>
    <xsl:if test="@configured=$False">
     <xsl:call-template name="kRequiresConfiguration"/>
    </xsl:if>
   </xsl:with-param>
   <xsl:with-param name="active"
                   select="@reading=$False and /state/@configured=$True"/>
   <xsl:with-param name="key">R</xsl:with-param>
  </xsl:call-template>
  <xsl:text>,</xsl:text>

  <xsl:call-template name="make_menu_command">
   <xsl:with-param name="command">connect</xsl:with-param>
   <xsl:with-param name="name">
    <xsl:call-template name="kConnect"/>
   </xsl:with-param>
   <xsl:with-param name="help">
    <xsl:call-template name="kConnectTitle"/>
   </xsl:with-param>
   <xsl:with-param name="help_inactive">
    <xsl:if test="@connected=$True">
     <xsl:call-template name="kConnectInfo"/>
    </xsl:if>
    <xsl:if test="@configured=$False">
     <xsl:call-template name="kRequiresConfiguration"/>
    </xsl:if>
   </xsl:with-param>
   <xsl:with-param name="active"
                   select="@connected=$False and /state/@configured=$True"/>
   <xsl:with-param name="key">C</xsl:with-param>
  </xsl:call-template>
  <xsl:text>,{},</xsl:text>

  <xsl:if test="$is_root_menu=$True">
   <xsl:call-template name="make_menu_command">
    <xsl:with-param name="command">stop_take</xsl:with-param>
    <xsl:with-param name="name">
     <xsl:call-template name="kStopTake"/>
    </xsl:with-param>
    <xsl:with-param name="help">
     <xsl:call-template name="kStopTakeTitle"/>
    </xsl:with-param>
    <xsl:with-param name="help_inactive">
     <xsl:if test="@taking=$False and @configured=$True">
      <xsl:call-template name="kStopTakeInfo"/>
     </xsl:if>
     <xsl:if test="@configured=$False">
      <xsl:call-template name="kRequiresConfiguration"/>
     </xsl:if>
    </xsl:with-param>
    <xsl:with-param name="active"
                    select="@taking=$True and @configured=$True"/>
    <xsl:with-param name="key">T</xsl:with-param>
   </xsl:call-template>
   <xsl:text>,</xsl:text>
  </xsl:if>

  <xsl:call-template name="make_menu_command">
   <xsl:with-param name="command">stop</xsl:with-param>
   <xsl:with-param name="name">
    <xsl:call-template name="kStopReading"/>
   </xsl:with-param>
   <xsl:with-param name="help">
    <xsl:call-template name="kStopReadingTitle"/>
   </xsl:with-param>
   <xsl:with-param name="help_inactive">
    <xsl:if test="@reading=$False and @configured=$True">
     <xsl:call-template name="kStopReadingInfo"/>
    </xsl:if>
    <xsl:if test="@configured=$False">
     <xsl:call-template name="kRequiresConfiguration"/>
    </xsl:if>
   </xsl:with-param>
   <xsl:with-param name="active"
                   select="@reading=$True and /state/@configured=$True"/>
   <xsl:with-param name="key">R</xsl:with-param>
  </xsl:call-template>
  <xsl:text>,</xsl:text>

  <xsl:call-template name="make_menu_command">
   <xsl:with-param name="command">close</xsl:with-param>
   <xsl:with-param name="name">
    <xsl:call-template name="kClose"/>
   </xsl:with-param>
   <xsl:with-param name="help">
    <xsl:call-template name="kCloseTitle"/>
   </xsl:with-param>
   <xsl:with-param name="help_inactive">
    <xsl:choose>
     <xsl:when test="$is_root_menu=$True">
      <xsl:if test="count(/state//node[@connected=$True])=0 and @configured=$True">
       <xsl:call-template name="kCloseInfo"/>
      </xsl:if>
     </xsl:when>
     <xsl:otherwise>
      <xsl:if test="@connected=$False">
       <xsl:call-template name="kCloseInfo"/>
      </xsl:if>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:if test="@configured=$False">
     <xsl:call-template name="kRequiresConfiguration"/>
    </xsl:if>
   </xsl:with-param>
   <xsl:with-param name="active"
                   select="@connected=$True or ($is_root_menu=$True and count(/state//node[@connected=$True])&gt;0)"/>
   <xsl:with-param name="key">
    <xsl:call-template name="CloseShortcut"/>
   </xsl:with-param>
  </xsl:call-template>
  <xsl:text>,{},</xsl:text>

  <xsl:if test="false and not(/*[@demo])">
   <xsl:call-template name="make_menu_command">
    <xsl:with-param name="command">set_gselect</xsl:with-param>
    <xsl:with-param name="name">
     <xsl:call-template name="kGSelect"/>
    </xsl:with-param>
    <xsl:with-param name="prompt">
     <xsl:call-template name="kGSelectPrompt"/>
    </xsl:with-param>
    <xsl:with-param name="value">
     <xsl:text>parseFloat(</xsl:text>
     <xsl:choose>
      <xsl:when test="string-length($node_gselect)">
       <xsl:value-of select="$node_gselect"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="GSelect"/>
      </xsl:otherwise>
     </xsl:choose>
     <xsl:text>)</xsl:text>
    </xsl:with-param>
    <xsl:with-param name="help">
     <xsl:call-template name="kGSelectTitle"/>
    </xsl:with-param>
    <xsl:with-param name="help_inactive">
     <xsl:if test="$is_root_menu=$False or @connected=$True">
      <xsl:call-template name="kRequiresClosed"/>
     </xsl:if>
     <xsl:if test="@configured=$False">
      <xsl:call-template name="kRequiresConfiguration"/>
     </xsl:if>
    </xsl:with-param>
    <xsl:with-param name="active"
                    select="@connected=$False and /state/@configured=$True"/>
    <xsl:with-param name="key">G</xsl:with-param>
   </xsl:call-template>
   <xsl:text>,</xsl:text>

   <xsl:if test="(@node_version and @node_version&lt;3) or count(//node[@node_version&lt;3])">
    <xsl:call-template name="make_menu_command">
     <xsl:with-param name="command">set_sample_rate</xsl:with-param>
     <xsl:with-param name="name">
      <xsl:call-template name="kSampleRate"/>
     </xsl:with-param>
     <xsl:with-param name="prompt">
      <xsl:call-template name="kSampleRatePrompt"/>
     </xsl:with-param>
     <xsl:with-param name="value">
      <xsl:text>parseFloat(</xsl:text>
      <xsl:choose>
       <xsl:when test="string-length($node_sample_rate)">
        <xsl:value-of select="$node_sample_rate"/>
       </xsl:when>
       <xsl:otherwise>
        <xsl:call-template name="SampleRate"/>
       </xsl:otherwise>
      </xsl:choose>
      <xsl:text>)</xsl:text>
     </xsl:with-param>
     <xsl:with-param name="help">
      <xsl:call-template name="kSampleRateTitle"/>
     </xsl:with-param>
     <xsl:with-param name="help_inactive">
      <xsl:if test="$is_root_menu=$False or @connected=$True">
       <xsl:call-template name="kRequiresClosed"/>
      </xsl:if>
      <xsl:if test="@configured=$False">
       <xsl:call-template name="kRequiresConfiguration"/>
      </xsl:if>
     </xsl:with-param>
     <xsl:with-param name="active"
                     select="@connected=$False and /state/@configured=$True"/>
     <xsl:with-param name="key">A</xsl:with-param>
    </xsl:call-template>
    <xsl:text>,</xsl:text>
   </xsl:if>

   <xsl:text>{},</xsl:text>
  </xsl:if>

  <xsl:if test="$is_root_menu=$True">
   <xsl:call-template name="make_menu_command">
    <xsl:with-param name="command">set_pose</xsl:with-param>
    <xsl:with-param name="name">
     <xsl:choose>
      <xsl:when test="$ShowTrack=1">
       <xsl:call-template name="kResetPosition"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="kSetPose"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:with-param>
    <xsl:with-param name="help">
     <xsl:call-template name="kSetPoseTitle"/>
    </xsl:with-param>
    <xsl:with-param name="help_inactive">
     <xsl:if test="@taking=$True">
      <xsl:call-template name="kSetPoseInfo"/>
     </xsl:if>
     <xsl:if test="@taking=$False and @configured=$True">
      <xsl:call-template name="kRequiresReading"/>
     </xsl:if>
    </xsl:with-param>
    <xsl:with-param name="active"
                    select="@reading=$True and @taking=$False"/>
    <xsl:with-param name="key">P</xsl:with-param>
   </xsl:call-template>
   <xsl:text>,</xsl:text>

   <!-- Show the rest pose command. -->
   <xsl:if test="$ShowTrack=1">
    <xsl:call-template name="make_menu_command">
     <xsl:with-param name="command">set_pose_marker</xsl:with-param>
     <xsl:with-param name="name">
      <xsl:call-template name="kRestPose"/>
     </xsl:with-param>
     <xsl:with-param name="help">
      <xsl:call-template name="kRestPoseTitle"/>
     </xsl:with-param>
     <xsl:with-param name="help_inactive">
      <xsl:if test="@taking=$True">
       <xsl:call-template name="kRestPoseInfo"/>
      </xsl:if>
      <xsl:if test="@taking=$False and @configured=$True">
       <xsl:call-template name="kRequiresReading"/>
      </xsl:if>
     </xsl:with-param>
     <xsl:with-param name="active"
                     select="@reading=$True and @taking=$False"/>
    </xsl:call-template>
    <xsl:text>,</xsl:text>
   </xsl:if>
   <xsl:text>{},</xsl:text>

   <xsl:call-template name="make_menu_command">
    <xsl:with-param name="command">insert</xsl:with-param>
    <xsl:with-param name="name">
     <xsl:call-template name="kInsert"/>
    </xsl:with-param>
    <xsl:with-param name="prompt">
     <xsl:call-template name="kInsertPrompt"/>
    </xsl:with-param>
    <xsl:with-param name="value">
     <xsl:text>'</xsl:text>
      <xsl:apply-templates select="history/@insert"/>
     <xsl:text>'</xsl:text>
    </xsl:with-param>
    <xsl:with-param name="help">
     <xsl:call-template name="kInsertTitle"/>
    </xsl:with-param>
    <xsl:with-param name="help_inactive">
     <xsl:call-template name="kRequiresClosed"/>
    </xsl:with-param>
    <xsl:with-param name="active"
                    select="@connected=$False and count(/state//node[@connected=$True])=0"/>
    <xsl:with-param name="key">I</xsl:with-param>
   </xsl:call-template>
   <xsl:text>,</xsl:text>
  </xsl:if>

  <xsl:if test="$is_root_menu!=$True">
   <xsl:if test="/state/@tracking=$True and @bus=$True and starts-with(@name,'Body') and node[starts-with(@name,'Hips')]">
    <xsl:call-template name="make_menu_command">
     <xsl:with-param name="command">set_pose_marker</xsl:with-param>
     <xsl:with-param name="name">
      <xsl:call-template name="kRestPose"/>
     </xsl:with-param>
     <xsl:with-param name="help">
      <xsl:call-template name="kRestPoseTitle"/>
     </xsl:with-param>
     <xsl:with-param name="help_inactive">
      <xsl:if test="/state/@taking=$True">
       <xsl:call-template name="kRestPoseInfo"/>
      </xsl:if>
      <xsl:if test="/state/@taking=$False and @configured=$True">
       <xsl:call-template name="kRequiresReading"/>
      </xsl:if>
     </xsl:with-param>
     <xsl:with-param name="active"
                     select="@reading=$True and /state/@taking=$False"/>
    </xsl:call-template>
    <xsl:text>,{},</xsl:text>
   </xsl:if>
  </xsl:if>

  <xsl:call-template name="make_menu_command">
   <xsl:with-param name="command">erase</xsl:with-param>
   <xsl:with-param name="name">
    <xsl:call-template name="kErase"/>
   </xsl:with-param>
   <xsl:with-param name="prompt">
    <xsl:if test="$is_root_menu=$True">
     <xsl:call-template name="kErasePrompt"/>
    </xsl:if>
   </xsl:with-param>
   <xsl:with-param name="help">
    <xsl:call-template name="kEraseTitle"/>
   </xsl:with-param>
   <xsl:with-param name="help_inactive">
    <xsl:if test="@connected=$True or count(/state//node[@connected=$True])">
     <xsl:call-template name="kRequiresClosed"/>
    </xsl:if>
    <xsl:if test="@configured=$False">
     <xsl:call-template name="kRequiresConfiguration"/>
    </xsl:if>
   </xsl:with-param>
   <xsl:with-param name="active"
                   select="@connected=$False and count(/state//node[@connected=$True])=0 and /state/@configured=$True"/>
   <xsl:with-param name="key">E</xsl:with-param>
  </xsl:call-template>

  <xsl:if test="$is_root_menu=$True">
   <xsl:text>,{},</xsl:text>
   <xsl:call-template name="make_menu_command">
    <xsl:with-param name="command">scan</xsl:with-param>
    <xsl:with-param name="name">
     <xsl:call-template name="kScan"/>
    </xsl:with-param>
    <xsl:with-param name="help">
     <xsl:call-template name="kScanTitle"/>
    </xsl:with-param>
    <xsl:with-param name="help_inactive">
     <xsl:call-template name="kRequiresClosed"/>
    </xsl:with-param>
    <xsl:with-param name="active"
                    select="@connected=$False and count(/state//node[@connected=$True])=0"/>
    <xsl:with-param name="key">N</xsl:with-param>
   </xsl:call-template>
  </xsl:if>

  <xsl:if test="$is_root_menu=$False and not(/*[@demo])">

   <xsl:text>,{},</xsl:text>
   <xsl:call-template name="make_menu_command">
    <xsl:with-param name="command">system.calibrate_from_take</xsl:with-param>
    <xsl:with-param name="name">
     <xsl:call-template name="kCalibrate"/>
    </xsl:with-param>
    <xsl:with-param name="help">
     <xsl:call-template name="kCalibrateTitle"/>
    </xsl:with-param>
    <xsl:with-param name="help_inactive">
     <xsl:call-template name="kCalibrateInfo"/>
    </xsl:with-param>
    <xsl:with-param name="active"
                    select="@connected=$False and count(/state/take)"/>
   </xsl:call-template>
   <xsl:text>,</xsl:text>

   <xsl:call-template name="make_menu_command">
    <xsl:with-param name="command">write_configuration</xsl:with-param>
    <xsl:with-param name="name">
     <xsl:call-template name="kWriteCalibration"/>
    </xsl:with-param>
    <xsl:with-param name="prompt">
     <xsl:call-template name="kWriteCalibrationPrompt"/>
    </xsl:with-param>
    <xsl:with-param name="help">
     <xsl:call-template name="kWriteCalibrationTitle"/>
    </xsl:with-param>
    <xsl:with-param name="help_inactive">
     <xsl:call-template name="kRequiresClosed"/>
    </xsl:with-param>
    <xsl:with-param name="active"
                    select="@connected=$False and not(@bus=$True)"/>
   </xsl:call-template>

   <xsl:if test="not(@bus=$True) and @source and ('bus'=substring(@source, 1, 3))">
    <xsl:text>,{},</xsl:text>

    <xsl:call-template name="make_menu_command">
     <xsl:with-param name="command">system.magnetic_from_take</xsl:with-param>
     <xsl:with-param name="name">
      <xsl:call-template name="kMagnetic"/>
     </xsl:with-param>
     <xsl:with-param name="help">
      <xsl:call-template name="kMagneticTitle"/>
     </xsl:with-param>
     <xsl:with-param name="help_inactive">
      <xsl:call-template name="kMagneticInfo"/>
     </xsl:with-param>
     <xsl:with-param name="active"
                     select="@connected=$True and count(/state/take)"/>
    </xsl:call-template>    
   </xsl:if>

   <xsl:if test="(@bus=$True) and @source and (('bus'=substring(@source, 1, 3)) or ('serial'=substring(@source, 1, 6)))">
    <xsl:text>,{},</xsl:text>
    <xsl:call-template name="make_menu_command">
     <xsl:with-param name="command">system.shutdown</xsl:with-param>
     <xsl:with-param name="name">
      <xsl:call-template name="kShutDown"/>
     </xsl:with-param>
     <xsl:with-param name="prompt">
      <xsl:call-template name="kShutDownPrompt"/>
     </xsl:with-param>
     <xsl:with-param name="help">
      <xsl:call-template name="kShutDownTitle"/>
     </xsl:with-param>
     <xsl:with-param name="help_inactive">
      <xsl:call-template name="kRequiresClosed"/>
     </xsl:with-param>
     <xsl:with-param name="active"
                     select="@connected=$False and count(/state//node[@connected=$True])=0"/>
    </xsl:call-template>
   </xsl:if>
  </xsl:if>

  <xsl:text>]</xsl:text>
 </xsl:template>

 <xsl:template match="log_path">
   <xsl:choose>
    <xsl:when test="string-length(text())&gt;0">
     <xsl:element name="a">
      <xsl:attribute name="title">
       <xsl:call-template name="kLogTitle"/>
      </xsl:attribute>
      <xsl:attribute name="href">
       <xsl:text>/</xsl:text>
       <xsl:apply-templates select="text()"/>
      </xsl:attribute>
      <xsl:attribute name="onclick">
       <xsl:text>GLI_EventListener.stop(event);</xsl:text>
      </xsl:attribute>
      <xsl:call-template name="kLog"/>
     </xsl:element>
    </xsl:when>
    <xsl:otherwise>
     <xsl:element name="a">
      <xsl:attribute name="title">
       <xsl:call-template name="kLogInactive"/>
      </xsl:attribute>
      <xsl:attribute name="style">
       <xsl:text>color: #676767; text-decoration: underline;</xsl:text>
      </xsl:attribute>
      <xsl:call-template name="kLog"/>
     </xsl:element>
    </xsl:otherwise>
   </xsl:choose> 
 </xsl:template>

 <!-- Shared template to generate Lua command in a JavaScript based menu. -->
 <xsl:template name="make_menu_command">
  <xsl:param name="command"/>
  <xsl:param name="name"/>
  <xsl:param name="prompt"/>
  <xsl:param name="value"/>
  <xsl:param name="help"/>
  <xsl:param name="help_inactive"/>
  <xsl:param name="key"/>
  <xsl:param name="active"/>

  <xsl:text>{command:'</xsl:text>
  <xsl:value-of select="$command"/>
  <xsl:text>',name:'</xsl:text>
  <xsl:value-of select="$name"/>
  <xsl:text>'</xsl:text>
  <xsl:if test="string-length($prompt)">
   <xsl:text>,prompt:'</xsl:text>
   <xsl:value-of select="$prompt"/>
   <xsl:text>'</xsl:text>
   <xsl:if test="string-length($value)">
    <xsl:text>,value:</xsl:text>
    <xsl:value-of select="$value"/>
   </xsl:if>
  </xsl:if>
  <xsl:if test="$active">
   <xsl:text>,active:true</xsl:text>
  </xsl:if>
  <xsl:text>,help:'</xsl:text>
  <xsl:value-of select="$help"/>
  <xsl:text>',help_inactive:'</xsl:text>
  <xsl:value-of select="$help_inactive"/>
  <xsl:text>'</xsl:text>
  <xsl:if test="string-length($key)">
   <xsl:text>,key:'</xsl:text>
   <xsl:value-of select="$key"/>
   <xsl:text>'</xsl:text>
  </xsl:if>
  <xsl:text>}</xsl:text>
 </xsl:template>

 <xsl:template name="escape_quote">
  <xsl:param name="quote">
   <xsl:text>'</xsl:text>
  </xsl:param>
  <xsl:param name="value"/>
  <xsl:choose>
   <xsl:when test="contains($value,$quote)">
    <xsl:value-of select="substring-before($value,$quote)"/>
    <xsl:text>\</xsl:text>
    <xsl:value-of select="$quote"/>
    <xsl:call-template name="escape_quote">
     <xsl:with-param name="value" select="substring-after($value,$quote)"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$value"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>
 
</xsl:stylesheet>
