<?xml version="1.0"?>
<!--
  Create an HTML version of the Motion Service export option file format.

  @file    static/style/export.xsl
  @author  Luke Tokheim, luke@motionnode.com
  @version 2.0
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:import href="common.xsl"/>
  <xsl:template name="Title">
    <xsl:text>Export</xsl:text>
  </xsl:template>
  <xsl:template name="LoadState">
    <xsl:value-of select="$False"/>
  </xsl:template>

  <xsl:template match="export">
   <xsl:element name="div">
     <xsl:attribute name="id">
       <xsl:text>export</xsl:text>
     </xsl:attribute>
     <xsl:element name="h1">
       <xsl:call-template name="Title"/>
     </xsl:element>

     <xsl:element name="form">
       <xsl:attribute name="onsubmit">
         <xsl:text>javascript:form_onsubmit(this); return false;</xsl:text>
       </xsl:attribute>
       <xsl:attribute name="action">#</xsl:attribute>
       <xsl:attribute name="method">get</xsl:attribute>
       <div class="row">
         <span class="title">
           <label for="filename">File</label>
         </span>
         <xsl:element name="input">
           <xsl:attribute name="id">filename</xsl:attribute>
           <xsl:attribute name="name">filename</xsl:attribute>
           <xsl:attribute name="type">text</xsl:attribute>
           <xsl:attribute name="size">50</xsl:attribute>
           <xsl:attribute name="value">
             <xsl:choose>
               <xsl:when test="//history[@export]">
                 <xsl:value-of select="//history/@export"/>
               </xsl:when>
               <xsl:otherwise>
                 <xsl:text>take</xsl:text>
                 <xsl:if test="format_list[@default]">
                   <xsl:text>.</xsl:text>
                   <xsl:value-of select="format_list/@default"/>
                 </xsl:if>
               </xsl:otherwise>
             </xsl:choose>
           </xsl:attribute>
           <xsl:attribute name="onchange">
             <xsl:text>javascript:form_filename_onchange(this);</xsl:text>
           </xsl:attribute>
         </xsl:element>
       </div>

       <div class="row">
         <span class="title">
           <label for="type">Type</label>
         </span>
         <xsl:apply-templates select="format_list" mode="form"/>
       </div>

       <div class="row">
         <span class="title">
           <xsl:element name="input">
             <xsl:attribute name="type">submit</xsl:attribute>
             <xsl:attribute name="value">Export to File</xsl:attribute>
           </xsl:element>
         </span>
         <xsl:text> </xsl:text>
         <xsl:element name="input">
           <xsl:attribute name="type">submit</xsl:attribute>
           <xsl:attribute name="value">Cancel</xsl:attribute>
           <xsl:attribute name="onclick">return false;</xsl:attribute>
         </xsl:element>
       </div>
     </xsl:element>
  </xsl:element>

  <script type="text/javascript">
  <xsl:text>
function form_filename_onchange(input)
{
  // Choose the type by filename extension.
  var match = /\.([^\.]+)$/i.exec(input.value);
  if (match) {
    var element = document.getElementById('type');
    if (element) {
      element.value = match[1].toLowerCase();
    }
  }
}

function form_type_change(input)
{
  if (input) {
    // Replace the extension on the filename.
    if (input.value) {
      var element = document.getElementById('filename');
      if (element) {
        element.value = element.value.replace(/\.([^\.]+)$/i, '.' + input.value);
      }
    }
    
    // Also select the hidden export options by type.
    var option = document.getElementById('option');
    if (option) {
      option.value = input.value;
    }
  }
}

function form_onsubmit()
{
  var filename = '';
  {
    var element = document.getElementById('filename');
    if (element) {
      filename = element.value;
    }
  }
  
  var option = '';
  {
    var element = document.getElementById('option');
    if (element) {
      option = element.value;
    }  
  }
  
  var type = '';
  {
    var element = document.getElementById('type');
    if (element) {
      type = element.value;
    }  
  }
  
  GLI_Command.send('export', filename, option, type);
  
  return false;
}
</xsl:text>
   </script>
  </xsl:template>

  <xsl:template match="format_list" mode="form">
    <xsl:element name="select">
      <xsl:attribute name="id">type</xsl:attribute>
      <xsl:attribute name="name">type</xsl:attribute>
      <xsl:attribute name="onchange">
        <xsl:text>javascript:form_type_change(this);</xsl:text>
      </xsl:attribute>
      <xsl:element name="option">
        <xsl:attribute name="value">
          <xsl:text></xsl:text>
        </xsl:attribute>
        <xsl:text>(*.*) Detect by extension</xsl:text>
      </xsl:element>
      <xsl:apply-templates select="format" mode="form"/>
    </xsl:element>

    <xsl:element name="select">
      <xsl:attribute name="id">option</xsl:attribute>
      <xsl:attribute name="name">option</xsl:attribute>
      <xsl:attribute name="disabled">1</xsl:attribute>
      <xsl:attribute name="style">visibility: hidden;</xsl:attribute>
      <xsl:element name="option"/>
      <xsl:apply-templates select="format" mode="form_option"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="format" mode="form">
    <xsl:variable name="ext">
      <xsl:value-of select="type"/>
    </xsl:variable>

    <xsl:element name="option">
      <xsl:attribute name="value">
        <xsl:value-of select="$ext"/>
      </xsl:attribute>
      <xsl:if test="../@default = $ext">
        <xsl:attribute name="selected">
          <xsl:text>1</xsl:text>
        </xsl:attribute>
      </xsl:if>
      <xsl:text>(*.</xsl:text>
      <xsl:value-of select="$ext"/>
      <xsl:text>) </xsl:text>
      <xsl:value-of select="description"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="format" mode="form_option">
    <xsl:variable name="ext">
      <xsl:value-of select="type"/>
    </xsl:variable>

    <xsl:element name="option">
      <xsl:attribute name="value">
        <xsl:value-of select="$ext"/>
      </xsl:attribute>
      <xsl:if test="../@default = $ext">
        <xsl:attribute name="selected">
          <xsl:text>1</xsl:text>
        </xsl:attribute>
      </xsl:if>
      <xsl:value-of select="option"/>
    </xsl:element>
  </xsl:template>

</xsl:stylesheet>