<?xml version="1.0"?>
<!--
  Create an HTML version of the Motion Service geocode file format, call it
  "Location".

  @file    static/style/geocode.xsl
  @author  Luke Tokheim, luke@motionnode.com
  @version 2.0
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:import href="common.xsl"/>
 <xsl:template name="Title">
  <xsl:call-template name="kLocation"/>
 </xsl:template>
 <xsl:template name="LoadState">
  <xsl:value-of select="$False"/>
 </xsl:template>
 <xsl:template name="FileUpload">
  <xsl:text>1</xsl:text>
 </xsl:template>

 <xsl:template match="geocode">
  <xsl:element name="script">
   <xsl:attribute name="type">
    <xsl:text>text/javascript</xsl:text>
   </xsl:attribute>
   <![CDATA[
    function browser_geocode() {
      GLI_Geolocation.get_location(function (lat, lng) {
        GLI_Command.send('system.geocode_address', [lat.toString(), ', ', lng.toString()].join(''));
      });
    }
    ]]>   
  </xsl:element>
  
  <xsl:element name="div">
   <xsl:attribute name="id">
    <xsl:text>geocode</xsl:text>
   </xsl:attribute>
   <xsl:attribute name="style">
    <xsl:text>width: 75%;</xsl:text>
   </xsl:attribute>

   <xsl:element name="h1">
    <xsl:call-template name="Title"/>
   </xsl:element>

   <xsl:element name="div">
    <xsl:attribute name="style">
     <xsl:text>margin-left: 1em;</xsl:text>
    </xsl:attribute> 
   
    <xsl:element name="p">
     <xsl:call-template name="kGeocodeSummary"/>
    </xsl:element>
    <xsl:element name="p">
     Enter either a street address or coordinates in decimal degrees.
     Another option is to
     <xsl:element name="a">
      <xsl:attribute name="href">
       <xsl:text>javascript:browser_geocode();</xsl:text>
      </xsl:attribute>
      <xsl:text>load the current location</xsl:text>
     </xsl:element>
     from your web browser.
    </xsl:element>

    <xsl:element name="table">
     <xsl:apply-templates select="location[@active&gt;0]" mode="selected"/>
    </xsl:element>

    <xsl:element name="div">
     <xsl:attribute name="style">
      <xsl:text>margin-top: 2em;</xsl:text>
     </xsl:attribute>

     <xsl:element name="p">
      Select a previously entered location. This will also enable location specific device calibrations.
     </xsl:element>

     <xsl:element name="table">
      <xsl:element name="tr">
       <xsl:element name="th">
        <xsl:text>Select Location</xsl:text>
       </xsl:element>
       <xsl:element name="td">
        <xsl:element name="select">
         <xsl:attribute name="onchange">
          <xsl:text>javascript:GLI_Command.send('system.geocode_address', this.options[this.selectedIndex].value);</xsl:text>
         </xsl:attribute>
         <xsl:apply-templates select="location"/>
        </xsl:element>
       </xsl:element>
      </xsl:element>
     </xsl:element>
    </xsl:element>

   </xsl:element>

  </xsl:element>

 </xsl:template>

 <!-- Expanded view. Show editable address field. -->
 <xsl:template match="location" mode="selected">
  <xsl:element name="tr">
   <xsl:element name="th">
    <xsl:call-template name="kAddress"/>
   </xsl:element>
   <xsl:call-template name="edit_element">
    <xsl:with-param name="command">
     <xsl:text>system.geocode_address</xsl:text>
    </xsl:with-param>
    <xsl:with-param name="text">
     <xsl:value-of select="address"/>
    </xsl:with-param>
   </xsl:call-template>
   <xsl:element name="td">
    <xsl:if test="string-length(point/latitude/text())&gt;0 and string-length(point/longitude/text())&gt;0">
     <xsl:element name="a">
      <xsl:attribute name="href">
       <xsl:call-template name="kMaps"/>
       <xsl:value-of select="point/latitude"/>
       <xsl:text>+</xsl:text>
       <xsl:value-of select="point/longitude"/>
      </xsl:attribute>
      <xsl:attribute name="target">
       <xsl:text>_blank</xsl:text>
      </xsl:attribute>
      <xsl:call-template name="kGeocodeMap"/>
     </xsl:element>
    </xsl:if>
   </xsl:element>  
  </xsl:element>
  <xsl:element name="tr">
   <xsl:element name="th">
    <xsl:call-template name="kLocation"/>
   </xsl:element>
   <xsl:element name="td">
    <xsl:apply-templates select="point/latitude"/>
    <xsl:apply-templates select="point/longitude"/>
    <xsl:apply-templates select="point/elevation"/>
   </xsl:element>
   <xsl:element name="td">
   </xsl:element>
  </xsl:element>
 </xsl:template>

 <!-- HTML based select list. -->
 <xsl:template match="location">
  <xsl:element name="option">
   <xsl:if test="@active&gt;0">
    <xsl:attribute name="selected">
     <xsl:text>1</xsl:text>
    </xsl:attribute>
   </xsl:if>
   <xsl:attribute name="value">
    <xsl:value-of select="point/latitude"/>
    <xsl:text>,</xsl:text>
    <xsl:value-of select="point/longitude"/>
    <xsl:text>,</xsl:text>
    <xsl:value-of select="point/elevation"/>
   </xsl:attribute>
   <xsl:value-of select="address"/>
  </xsl:element>
 </xsl:template>

 <!-- Override default rules for real valued numbers. Use a common output format.  -->
 <xsl:template match="latitude|longitude|elevation">
  <xsl:element name="span">
   <xsl:attribute name="class">
    <xsl:text>item</xsl:text>
   </xsl:attribute>
   <xsl:value-of select="format-number(text(),'0.##')"/>
   <xsl:if test="name()='elevation'">
    <xsl:text> </xsl:text>
    <xsl:call-template name="kMeter"/>
   </xsl:if>
  </xsl:element>
 </xsl:template>

</xsl:stylesheet>
