<?xml version="1.0"?>
<!--
  User interface to initialize Motion Service preferences. The "initialize" tree
  is generated by the main user interface Lua script.

  @file    static/style/initialize.xsl
  @author  Luke Tokheim, luke@motionnode.com
  @version 2.0
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:import href="common.xsl"/>
 <xsl:template name="Title">
  <xsl:call-template name="kPreferences"/>
 </xsl:template>

 <xsl:variable name="MenuFile">
  <xsl:text>[</xsl:text>
  <xsl:text>{command:'open',name:'Open'</xsl:text>
  <xsl:if test="not(/*[@demo])">
   <xsl:text>,active:true</xsl:text>
  </xsl:if>
  <xsl:text>,prompt:'Open file:',value:'</xsl:text> 
  <xsl:apply-templates select="/initialize/history/@open"/>
  <xsl:text>',help:'Open file.',key:'O'}</xsl:text>
  <xsl:text>,{command:'system.save_initialization',name:'Save'</xsl:text>
  <xsl:if test="/initialize/@valid=$True and not(/*[@demo])">
   <xsl:text>,active:true</xsl:text>
  </xsl:if>
  <xsl:text>,prompt:'Save current preferences?'</xsl:text>
  <xsl:text>,help:'Save current preferences.',help_inactive:'Requires a valid value for each initial preference field.'</xsl:text>
  <xsl:text>,key:'S'}</xsl:text>
  <xsl:text>,{}</xsl:text>
  <xsl:text>,{command:'export',name:'Export',help_inactive:'Requires an active take definition and non-empty configuration.'}</xsl:text>
  <xsl:text>]</xsl:text>
 </xsl:variable>

 <xsl:template name="JavascriptShortcut">
  <xsl:value-of select="$MenuFile"/>
 </xsl:template>

 <xsl:template match="initialize">
  <div style="padding-bottom: 3px; margin-bottom: 1em;">
   <xsl:call-template name="make_menubar">
    <xsl:with-param name="MenuFile">
     <xsl:value-of select="$MenuFile"/>
    </xsl:with-param>
    <xsl:with-param name="MenuNode">
     <xsl:call-template name="node_to_menu"/>
    </xsl:with-param>
    <xsl:with-param name="LinkLocation">
     <xsl:value-of select="@valid"/>
    </xsl:with-param>
   </xsl:call-template>
  </div>

  <div id="initialize" style="width: 75%;">
   <div>
    <h2>Welcome</h2>
    <p>
     Since this is your first time using the Motion software, please
     confirm the following preferences. We try to supply good
     default values as a starting point. Click on a field to
     edit it.
    </p>
    <p>
     <xsl:element name="table">
      <xsl:element name="tr">
       <xsl:attribute name="title">
        <xsl:text>Enter the address of the your geographic location.</xsl:text>
       </xsl:attribute>

       <xsl:element name="th">
        <xsl:element name="span">
         <xsl:if test="string-length(address/canonical/text())&gt;0">
          <xsl:text>* </xsl:text>
         </xsl:if>
         <xsl:text>Geographic Location:</xsl:text>
        </xsl:element>
       </xsl:element>

       <xsl:call-template name="edit_element">
        <xsl:with-param name="command">
         <xsl:text>system.geocode_address</xsl:text>
        </xsl:with-param>
        <xsl:with-param name="text">
         <xsl:choose>
          <xsl:when test="string-length(address/canonical/text())&gt;0">
           <xsl:apply-templates select="address/canonical/text()"/>
          </xsl:when>
          <xsl:otherwise>
           <xsl:choose>
            <xsl:when test="string-length(address/input/text())&gt;0">
             <xsl:apply-templates select="address/input/text()"/>
            </xsl:when>
            <xsl:otherwise>
             <xsl:text>Enter the address of the your geographic location</xsl:text>
            </xsl:otherwise>
           </xsl:choose>
          </xsl:otherwise>
         </xsl:choose>
        </xsl:with-param>
       </xsl:call-template>

       <xsl:element name="td">
        <xsl:if test="@valid=$True">
         <xsl:element name="a">
          <xsl:attribute name="title">
           <xsl:text>Show this location in an online map</xsl:text>
          </xsl:attribute>
          <xsl:attribute name="href">
           <xsl:call-template name="kMaps"/>
           <xsl:apply-templates select="location/latitude/text()"/>
           <xsl:text>+</xsl:text>
           <xsl:apply-templates select="location/longitude/text()"/>
          </xsl:attribute>
          <xsl:attribute name="target">
           <xsl:text>_blank</xsl:text>
          </xsl:attribute>
          <xsl:text>Show in online map</xsl:text>
         </xsl:element>
        </xsl:if>
       </xsl:element>
      </xsl:element>
     </xsl:element>
     
    </p>
    <div style="margin-left: 1em;">
     <p>
      Set your geographic location. This is required to estimate the magnetic field
      of the Earth, which varies based on physical location. There are three methods
      to enter your location.
     </p>
     <ol>
      <li style="margin-bottom: 1em;">
       Enter your street address. The system looks up latitude, longitude, and elevation
       in a database over your internet connection. For example, enter <em>400 Broad St, Seattle WA</em>
       if you are using your MotionNode sensor at the Space Needle.
      </li>
      <li style="margin-bottom: 1em;">
       Use the location supplied
       <xsl:element name="a">
        <xsl:attribute name="href">
         <xsl:text>javascript:GLI_Geolocation.get_location(function (lat, lng) { GLI_Command.send('system.geocode_address', lat + ', ' + lng); })</xsl:text>
        </xsl:attribute>
        <xsl:text>by your web browser</xsl:text>
       </xsl:element>.
       You may need to give permission for this page to use your location.
      </li>
      <li style="margin-bottom: 1em;">
       Specify your location coordinates manually. For example, enter <em>47.62 -122.35 40</em> for
       your latitude and longitude in decimal degrees, followed by elevation in meters (optional).
       This method does not require an internet connection.
      </li>
     </ol>
    </div>

    <xsl:element name="div">
     <xsl:element name="table">

      <xsl:element name="tr">
       <xsl:attribute name="title">
        <xsl:text>Enter the folder name for take, configuration, and export data.</xsl:text>
       </xsl:attribute>

       <xsl:element name="th">
        <xsl:if test="string-length(data_path/text())&gt;0">
         <xsl:text>* </xsl:text>
        </xsl:if>
        <xsl:text>Data Folder:</xsl:text>
       </xsl:element>

       <xsl:call-template name="edit_element">
        <xsl:with-param name="command">
         <xsl:text>system.set_data_path</xsl:text>
        </xsl:with-param>
        <xsl:with-param name="text">
         <xsl:choose>
          <xsl:when test="string-length(data_path/text())&gt;0">
           <xsl:apply-templates select="data_path/text()"/>
          </xsl:when>
          <xsl:otherwise>
           <xsl:text>Enter folder name for user data</xsl:text>
          </xsl:otherwise>
         </xsl:choose>
        </xsl:with-param>
       </xsl:call-template>
      </xsl:element>

     </xsl:element>
    </xsl:element>

    <div style="margin-left: 1em;">
     <p>
      Enter the folder where all of your user specific Motion data
      is stored. This includes take data, configuration files, and
      export files.
     </p>
    </div>

    <p>
     After all fields have valid values (<b>*</b>),
     <xsl:element name="a">
      <xsl:if test="@valid=$True">
       <xsl:attribute name="href">
        <xsl:text>javascript:GLI_Command.send_confirm('system.save_initialization','Save current preferences?')</xsl:text>
       </xsl:attribute>
      </xsl:if>
      <xsl:text>save the current preferences</xsl:text>
     </xsl:element> to continue.
    </p>

    <p>
     <xsl:element name="input">
      <xsl:attribute name="type">submit</xsl:attribute>
      <xsl:attribute name="value">Save and Continue</xsl:attribute>
      <xsl:attribute name="size">50</xsl:attribute>
      <xsl:if test="@valid!=$True">
       <xsl:attribute name="disabled">disabled</xsl:attribute>
      </xsl:if>
      <xsl:attribute name="onclick">
       <xsl:text>javascript:GLI_Command.send_confirm('system.save_initialization','Save current preferences?')</xsl:text>
      </xsl:attribute>
     </xsl:element>
    </p>
    
   </div>

  </div>

 </xsl:template>

</xsl:stylesheet>
