<?xml version="1.0"?>
<!--
  Create an HTML version of the Motion Service ractor file format, call it
  "Ractor".

  @file    static/style/ractor.xsl
  @author  Luke Tokheim, luke@motionnode.com
  @version 2.0
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:import href="common.xsl"/>
 <xsl:template name="Title">
  <xsl:text>Ractor</xsl:text>
 </xsl:template>
 <xsl:template name="LoadState">
  <xsl:value-of select="$False"/>
 </xsl:template>
 <xsl:template name="FileUpload">
  <xsl:text>1</xsl:text>
 </xsl:template>

 <xsl:template match="ractor">
  <xsl:element name="div">
   <xsl:attribute name="id">
    <xsl:text>ractor</xsl:text>
   </xsl:attribute>
   <xsl:attribute name="style">
    <xsl:text>width: 75%;</xsl:text>
   </xsl:attribute>

   <xsl:element name="h1">
    <xsl:call-template name="Title"/>
   </xsl:element>

   <p>
    Enter performer measurements to scale the output skeleton. The default
    height is 178 cm, approximately 5' 10".
   </p>

   <xsl:choose>
    <xsl:when test="count(definition[@active&gt;0]) = 1">
     <xsl:apply-templates select="definition[@active&gt;0]" mode="selected"/>

     <div class="spacer">&#160;</div>

     <div class="row">
      <span class="title">
       <label for="ractor_select">Select Ractor</label>
      </span>

      <xsl:element name="select">
       <xsl:attribute name="id">
        <xsl:text>ractor_select</xsl:text>
       </xsl:attribute>
       <xsl:attribute name="name">
        <xsl:text>ractor_select</xsl:text>
       </xsl:attribute>
       <xsl:attribute name="onchange">
        <xsl:text>javascript:GLI_Command.send('system.ractor', this.options[this.selectedIndex].value);</xsl:text>
       </xsl:attribute>
       <xsl:apply-templates select="definition" mode="option"/>
      </xsl:element>

     </div>

    </xsl:when>
    <xsl:otherwise>
     <xsl:apply-templates select="definition" mode="selected"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:element>

  <script type="text/javascript">
   <xsl:text>
   function ractor_change(element)
   {
     var name = "";
     var height = 0;
     var arm = 0;
     var leg = 0;
     
     var element = document.getElementById("name");
     if (null !== element) {
       name = element.value;
     }
     
     element = document.getElementById("height");
     if (null !== element) {
       height = parseFloat(element.value);
     }
     
     element = document.getElementById("arm");
     if (null !== element) {
       arm = parseFloat(element.value);
     }
     
     element = document.getElementById("leg");
     if (null !== element) {
       leg = parseFloat(element.value);
     }
     
     GLI_Command.send("system.ractor", name, height, arm, leg);
   }
   </xsl:text>
  </script>
 </xsl:template>

 <!-- Expanded view. Show editable address field. -->
 <xsl:template match="definition" mode="selected">

  <form name="ractor_form">
   <div class="indent">
    <div class="row">
     <span class="title">
      <label for="name">Name</label>
     </span>
     <input id="name" name="name" onchange="javascript:ractor_change(this);">
      <xsl:attribute name="value">
       <xsl:value-of select="name"/>
      </xsl:attribute>
     </input>
     <p class="indent">
      Enter the name of the performer.
     </p>
    </div>

    <div class="row">
     <span class="title">
      <label for="height">Height</label>
     </span>
     <input id="height" name="height" onchange="javascript:ractor_change(this);" size="4">
      <xsl:attribute name="value">
       <xsl:value-of select="measurement/height"/>
      </xsl:attribute>
     </input> 
     <p class="indent">
      Height of the performer. Enter in centimeters (cm). Round to nearest
      centimeter.
     </p>
    </div>

    <div class="row">
     <span class="title">
      <label for="arm">Arm</label>
     </span>
     <input id="arm" name="arm" onchange="javascript:ractor_change(this);" size="4">
      <xsl:attribute name="value">
       <xsl:value-of select="measurement/arm"/>
      </xsl:attribute>
     </input>
     <p class="indent">
      Wing span of the performer. Measure from finger tip to finger tip.
     </p>
     <p class="indent">
      A good estimate is that the height and wing span are the equal.
     </p>
    </div>

    <div class="row">
     <span class="title">
      <label for="leg">Leg</label>
     </span>
     <input id="leg" name="leg" onchange="javascript:ractor_change(this);" size="4">
      <xsl:attribute name="value">
       <xsl:value-of select="measurement/leg"/>
      </xsl:attribute>
     </input>
     <p class="indent">
      Leg length of the performer. Measure the seated height of the performer.
      Subtract from the total height to get the leg length.
     </p>
     <p class="indent">
      A good estimate is that the leg length is half of the height.
     </p>
    </div>
   </div>
  </form>

 </xsl:template>

 <!-- HTML drop down list view. -->
 <xsl:template match="definition" mode="option">
  <xsl:element name="option">
   <xsl:if test="@active&gt;0">
    <xsl:attribute name="selected">
     <xsl:text>1</xsl:text>
    </xsl:attribute>
   </xsl:if>
   <xsl:attribute name="value">
    <xsl:value-of select="name"/>
   </xsl:attribute>
   <xsl:value-of select="name"/>
   <xsl:text> - </xsl:text>
   <xsl:value-of select="measurement/height"/>
   <xsl:text>, </xsl:text>
   <xsl:value-of select="measurement/arm"/>
   <xsl:text>, </xsl:text>
   <xsl:value-of select="measurement/leg"/>
   <xsl:text> cm</xsl:text>
  </xsl:element>
 </xsl:template>
 
</xsl:stylesheet>
