<?xml version="1.0"?>
<!--
  Main user interface to the Motion Service. The "state" tree is generated by
  the main user interface Lua script. The "state" tree contains a current
  snapshot of the status of the system.

  @file    static/style/state.xsl
  @author  Luke Tokheim, luke@motionnode.com
  @version 2.0
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:import href="common.xsl"/>
 <xsl:template name="Title">
  <xsl:call-template name="kStatus"/>
 </xsl:template>
 <xsl:template name="Monitor">
  <xsl:choose>
   <xsl:when test="/state[@connected=$True or count(/state//node[@connected=$True])&gt;0]">
    <xsl:text>1</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>10</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>
 <xsl:template name="FileUpload">
  <xsl:text>1</xsl:text>
 </xsl:template>

 <xsl:template name="JavascriptShortcut">
  <xsl:value-of select="$MenuFile"/>
  <xsl:text>.concat(</xsl:text>
  <xsl:value-of select="$MenuNode"/>
  <xsl:text>)</xsl:text>
 </xsl:template>

 <xsl:variable name="EditConfiguration">
  <xsl:value-of select="$False"/>
 </xsl:variable>

 <xsl:variable name="DefaultOpen">
  <xsl:choose>
   <xsl:when test="string-length(//history/@open)&gt;0">
    <xsl:call-template name="escape_quote">
     <xsl:with-param name="value">
      <xsl:apply-templates select="//history/@open"/>
     </xsl:with-param>
    </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="ConfigurationFile"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:variable>
 <xsl:variable name="DefaultExport">
  <xsl:choose>
   <xsl:when test="string-length(//history/@export)&gt;0">
    <xsl:call-template name="escape_quote">
     <xsl:with-param name="value">
      <xsl:apply-templates select="//history/@export"/>
     </xsl:with-param>
    </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="TakeFile"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:variable>
 <xsl:variable name="DefaultExportStream">
  <xsl:choose>
   <xsl:when test="string-length(//history/@export_stream)&gt;0">
    <xsl:call-template name="escape_quote">
     <xsl:with-param name="value">
      <xsl:apply-templates select="//history/@export_stream"/>
     </xsl:with-param>
    </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="ExportStreamFile"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:variable>
 <xsl:variable name="DefaultSave">
  <xsl:choose>
   <xsl:when test="string-length(//history/@save_configuration)&gt;0">
    <xsl:call-template name="escape_quote">
     <xsl:with-param name="value">
      <xsl:apply-templates select="//history/@save_configuration"/>
     </xsl:with-param>
    </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="ConfigurationFile"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:variable>

 <xsl:variable name="MenuFile">
  <xsl:text>[</xsl:text>
  <xsl:call-template name="make_menu_command">
   <xsl:with-param name="command">open</xsl:with-param>
   <xsl:with-param name="name">
    <xsl:call-template name="kOpen"/>
   </xsl:with-param>
   <xsl:with-param name="prompt">
    <xsl:call-template name="kOpenPrompt"/>
   </xsl:with-param>
   <xsl:with-param name="value">
    <xsl:text>'</xsl:text>
    <xsl:value-of select="$DefaultOpen"/>
    <xsl:text>'</xsl:text>
   </xsl:with-param>
   <xsl:with-param name="help">
    <xsl:call-template name="kOpenTitle"/>
   </xsl:with-param>
   <xsl:with-param name="help_inactive">
    <xsl:call-template name="kRequiresClosed"/>
   </xsl:with-param>
   <xsl:with-param name="active"
                   select="/state/@connected=$False and count(/state//node[@connected=$True])=0"/>
   <xsl:with-param name="key">O</xsl:with-param>
  </xsl:call-template>
  <xsl:text>,</xsl:text>

  <xsl:call-template name="make_menu_command">
   <xsl:with-param name="command">save_configuration</xsl:with-param>
   <xsl:with-param name="name">
    <xsl:call-template name="kSave"/>
   </xsl:with-param>
   <xsl:with-param name="prompt">
    <xsl:call-template name="kSavePrompt"/>
   </xsl:with-param>
   <xsl:with-param name="value">
    <xsl:text>'</xsl:text>
    <xsl:value-of select="$DefaultSave"/>
    <xsl:text>'</xsl:text>
   </xsl:with-param>
   <xsl:with-param name="help">
    <xsl:call-template name="kSaveTitle"/>
   </xsl:with-param>
   <xsl:with-param name="help_inactive">
    <xsl:call-template name="kSaveInfo"/>
   </xsl:with-param>
   <xsl:with-param name="active"
                   select="/state/@configured=$True"/>
   <xsl:with-param name="key">S</xsl:with-param>
  </xsl:call-template>
  <xsl:text>,{},</xsl:text>

  <xsl:call-template name="make_menu_command">
   <xsl:with-param name="command">export</xsl:with-param>
   <xsl:with-param name="name">
    <xsl:call-template name="kExport"/>
   </xsl:with-param>
   <xsl:with-param name="prompt">
    <xsl:call-template name="kExportPrompt"/>
   </xsl:with-param>
   <xsl:with-param name="value">
    <xsl:text>'</xsl:text>
    <xsl:value-of select="$DefaultExport"/>
    <xsl:text>'</xsl:text>
   </xsl:with-param>
   <xsl:with-param name="help">
    <xsl:call-template name="kExportTitle"/>
   </xsl:with-param>
   <xsl:with-param name="help_inactive">
    <xsl:call-template name="kExportInfo"/>
   </xsl:with-param>
   <xsl:with-param name="active"
                   select="count(/state/take) and /state/@configured=$True"/>
   <xsl:with-param name="key">X</xsl:with-param>
  </xsl:call-template>
  <xsl:text>,</xsl:text>

  <xsl:call-template name="make_menu_command">
   <xsl:with-param name="command">export_stream</xsl:with-param>
   <xsl:with-param name="name">
    <xsl:call-template name="kExportStream"/>
   </xsl:with-param>
   <xsl:with-param name="prompt">
    <xsl:call-template name="kExportStreamPrompt"/>
   </xsl:with-param>
   <xsl:with-param name="value">
    <xsl:text>'</xsl:text>
    <xsl:value-of select="$DefaultExportStream"/>
    <xsl:text>'</xsl:text>
   </xsl:with-param>
   <xsl:with-param name="help">
    <xsl:call-template name="kExportStreamTitle"/>
   </xsl:with-param>
   <xsl:with-param name="help_inactive">
    <xsl:call-template name="kExportInfo"/>
   </xsl:with-param>
   <xsl:with-param name="active"
                   select="count(/state/take) and /state/@configured=$True"/>
   <xsl:with-param name="key">M</xsl:with-param>
  </xsl:call-template>
  <xsl:text>]</xsl:text>
 </xsl:variable>

 <xsl:variable name="MenuNode">
  <xsl:for-each select="/state[position()=1]">
   <xsl:call-template name="node_to_menu"/>
  </xsl:for-each>
 </xsl:variable>

 <xsl:variable name="MenuBus">
  <xsl:text>[</xsl:text>
  <xsl:call-template name="make_menu_command">
   <xsl:with-param name="command">system.shutdown</xsl:with-param>
   <xsl:with-param name="name">
    <xsl:call-template name="kShutDown"/>
   </xsl:with-param>
   <xsl:with-param name="prompt">
    <xsl:call-template name="kShutDownPrompt"/>
   </xsl:with-param>
   <xsl:with-param name="help">
    <xsl:call-template name="kShutDownTitle"/>
   </xsl:with-param>
   <xsl:with-param name="active">true</xsl:with-param>
  </xsl:call-template>
  <xsl:text>]</xsl:text>
 </xsl:variable>

 <xsl:template match="state">
  <xsl:element name="div">
   <div style="margin-bottom: 1em;">
    <xsl:call-template name="make_menubar">
     <xsl:with-param name="MenuFile">
      <xsl:value-of select="$MenuFile"/>
     </xsl:with-param>
     <xsl:with-param name="MenuNode">
      <xsl:value-of select="$MenuNode"/>
     </xsl:with-param>
     <xsl:with-param name="MenuBus">
      <xsl:if test="@version_bus">
       <xsl:value-of select="$MenuBus"/>
      </xsl:if>
     </xsl:with-param>
    </xsl:call-template>
   </div>

   <xsl:choose>
    <xsl:when test="string-length(configuration/@detail) &gt; 0">
     <div id="detail">
      <xsl:apply-templates select="configuration" mode="detail"/>
     </div>
    </xsl:when>
    <xsl:otherwise>
     <div id="configuration">
      <table>
       <thead>
        <tr>
         <th>
          <xsl:element name="a">
           <xsl:attribute name="title">
            <xsl:call-template name="kIdTitle"/>
           </xsl:attribute>
           <xsl:call-template name="kId"/>
          </xsl:element>
         </th>
         <th>
          <xsl:element name="a">
           <xsl:attribute name="title">
            <xsl:call-template name="kNameTitle"/>
           </xsl:attribute>
           <xsl:call-template name="kName"/>
          </xsl:element>
         </th>
         <th>
          <xsl:element name="a">
           <xsl:attribute name="title">
            <xsl:call-template name="kSourceTitle"/>
           </xsl:attribute>
           <xsl:call-template name="kSource"/>
          </xsl:element>
         </th>
         <th>
          <xsl:element name="a">
           <xsl:attribute name="title">
            <xsl:call-template name="kConnectedTitle"/>
           </xsl:attribute>
           <xsl:call-template name="kConnected"/>
          </xsl:element>
         </th>
         <th>
          <xsl:element name="a">
           <xsl:attribute name="title">
            <xsl:call-template name="kReadingTitle"/>
           </xsl:attribute>
           <xsl:call-template name="kReading"/>
          </xsl:element>
         </th>
         <th>
         </th>
        </tr>
       </thead>
       <tbody>
        <xsl:if test="count(configuration/node)=0">
         <tr>
          <td colspan="7" style="text-align: center; font-style: italic; color: #676767;">
           <xsl:call-template name="kEmptyConfiguration"/>
          </td>
         </tr>
        </xsl:if>
        <xsl:apply-templates select="configuration/node"/>
       </tbody>
      </table>
     </div>
    </xsl:otherwise>
   </xsl:choose>

  </xsl:element>
 </xsl:template>

 <xsl:template match="configuration[@detail]" mode="detail">
  <xsl:variable name="node_detail">
   <xsl:value-of select="@detail"/>
  </xsl:variable>
  <xsl:apply-templates select=".//node[@id=$node_detail]" mode="detail"/>
 </xsl:template>

 <xsl:template match="node">
  <xsl:element name="tr">
   <xsl:element name="td">
    <xsl:attribute name="onclick">
     <xsl:text>javascript:GLI_Menu.open(event,this,</xsl:text>
     <xsl:call-template name="node_to_menu"/>
     <xsl:text>,'</xsl:text>
     <xsl:value-of select="@id"/>
     <xsl:text>')</xsl:text>
    </xsl:attribute>
    <xsl:attribute name="style">cursor: pointer;</xsl:attribute>
    <xsl:attribute name="class">read_only</xsl:attribute>
    <xsl:apply-templates select="@id"/>
   </xsl:element>

   <xsl:choose>
    <xsl:when test="@connected=$True">
     <xsl:element name="td">
      <xsl:attribute name="class">read_only</xsl:attribute>
      <xsl:apply-templates select="@name"/>
     </xsl:element>
     <xsl:element name="td">
      <xsl:attribute name="class">read_only</xsl:attribute>
      <xsl:apply-templates select="@source"/>
     </xsl:element>
    </xsl:when>
    <xsl:otherwise>
     <xsl:call-template name="edit_element">
      <xsl:with-param name="id" select="@id"/>
      <xsl:with-param name="command" select="'set_name'"/>
      <xsl:with-param name="text" select="@name"/>
     </xsl:call-template>

     <xsl:call-template name="edit_element">
      <xsl:with-param name="id" select="@id"/>
      <xsl:with-param name="command" select="'set_source'"/>
      <xsl:with-param name="text" select="@source"/>
     </xsl:call-template>
    </xsl:otherwise>
   </xsl:choose>

   <xsl:choose>
    <xsl:when test="string-length(@parent)=0">
     <xsl:element name="td">
      <xsl:attribute name="style">text-align: center;</xsl:attribute>
      <xsl:attribute name="class">read_only</xsl:attribute>

      <xsl:element name="input">
       <xsl:attribute name="type">checkbox</xsl:attribute>
       <xsl:if test="@connected=$True">
        <xsl:attribute name="checked">1</xsl:attribute>
       </xsl:if>
       <xsl:if test="@active=$False">
        <xsl:attribute name="disabled">1</xsl:attribute>
       </xsl:if>
       <xsl:attribute name="onclick">
        <xsl:text>javascript:GLI_Command.send('</xsl:text>
        <xsl:choose>
         <xsl:when test="@connected=$True">
          <xsl:text>close</xsl:text>
         </xsl:when>
         <xsl:otherwise>
          <xsl:text>connect</xsl:text>
         </xsl:otherwise>
        </xsl:choose>
        <xsl:text>','</xsl:text>
        <xsl:value-of select="@id"/>
        <xsl:text>')</xsl:text>
       </xsl:attribute>
      </xsl:element>

     </xsl:element>
     <xsl:element name="td">
      <xsl:attribute name="style">text-align: center;</xsl:attribute>
      <xsl:attribute name="class">read_only</xsl:attribute>

      <xsl:element name="input">
       <xsl:attribute name="type">checkbox</xsl:attribute>
       <xsl:if test="@reading=$True">
        <xsl:attribute name="checked">1</xsl:attribute>
       </xsl:if>
       <xsl:if test="@active=$False">
        <xsl:attribute name="disabled">1</xsl:attribute>
       </xsl:if>
       <xsl:attribute name="onclick">
        <xsl:text>javascript:GLI_Command.send('</xsl:text>
        <xsl:choose>
         <xsl:when test="@reading=$True">
          <xsl:text>stop</xsl:text>
         </xsl:when>
         <xsl:otherwise>
          <xsl:text>start</xsl:text>
         </xsl:otherwise>
        </xsl:choose>
        <xsl:text>','</xsl:text>
        <xsl:value-of select="@id"/>
        <xsl:text>')</xsl:text>
       </xsl:attribute>
      </xsl:element>

     </xsl:element>

    </xsl:when>
    <xsl:otherwise>
     <xsl:element name="td">
      <xsl:attribute name="class">read_only</xsl:attribute>
      <xsl:attribute name="colspan">2</xsl:attribute>
      <xsl:attribute name="style">text-align: center;</xsl:attribute>
     <xsl:text>--</xsl:text>
     </xsl:element>
    </xsl:otherwise>
   </xsl:choose>

   <xsl:element name="td">
    <xsl:attribute name="style">text-align: center;</xsl:attribute>
    <xsl:attribute name="class">read_only</xsl:attribute>
    <xsl:element name="small">

     <xsl:element name="a">
      <xsl:attribute name="title">
       <xsl:call-template name="kDetailTitle"/>
      </xsl:attribute>
      <xsl:attribute name="href">
       <xsl:text>?detail=</xsl:text>
       <xsl:value-of select="@id"/>
      </xsl:attribute>
      <xsl:call-template name="kDetail"/>
     </xsl:element>

    </xsl:element>
   </xsl:element>

  </xsl:element>

  <xsl:apply-templates select="bus|node"/>
 </xsl:template>

 <xsl:template match="node" mode="detail">
  <xsl:element name="h2">
   <a name="id">
    <xsl:choose>
     <xsl:when test="@key&gt;0">
      <xsl:value-of select="@id"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="kDefaultConfigurationValues"/>
     </xsl:otherwise>
    </xsl:choose>
   </a>
  </xsl:element>

  <xsl:if test="@key=0">
   <p class="indent">
    View and edit the default configuration parameters. New
    configuration entries will use these values.
   </p>
  </xsl:if>

  <div class="indent">
   <xsl:if test="@key&gt;0">
    <div class="row">
     <span class="title">
      <a name="status"><xsl:call-template name="kStatus"/></a>
     </span>
     <xsl:element name="span">
      <xsl:choose>
       <xsl:when test="/state/@taking=$True">
        <xsl:call-template name="kRecording"/>
       </xsl:when>
       <xsl:otherwise>
        <xsl:choose>
         <xsl:when test="@reading=$True">
          <xsl:call-template name="kReading"/>
         </xsl:when>
         <xsl:otherwise>
          <xsl:choose>
           <xsl:when test="@connected=$True">
            <xsl:call-template name="kConnected"/>
           </xsl:when>
           <xsl:otherwise>
            <xsl:call-template name="kClosed"/>
           </xsl:otherwise>
          </xsl:choose>
         </xsl:otherwise>
        </xsl:choose>
       </xsl:otherwise>
      </xsl:choose>
     </xsl:element>
     <p class="indent">
      Current status of this configuration entry.
     </p>
    </div>

    <div class="row">
     <span class="title">
      <a name="name"><xsl:call-template name="kName"/></a>
     </span>
     <xsl:choose>
      <xsl:when test="@connected=$True">
       <xsl:element name="span">
        <xsl:attribute name="class">read_only</xsl:attribute>
        <xsl:apply-templates select="@name"/>
       </xsl:element>
      </xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="edit_element">
        <xsl:with-param name="id" select="@id"/>
        <xsl:with-param name="command" select="'set_name'"/>
        <xsl:with-param name="element" select="'span'"/>
        <xsl:with-param name="text" select="@name"/>
       </xsl:call-template>
      </xsl:otherwise>
     </xsl:choose>
     <p class="indent">
      Any name for the device. Not necessarily unique. Saved in configuration
      and take files.
     </p>
    </div>

    <div class="row">
     <span class="title">
      <a name="source"><xsl:call-template name="kSource"/></a>
     </span>
     <xsl:choose>
      <xsl:when test="@connected=$True">
       <xsl:element name="span">
        <xsl:attribute name="class">read_only</xsl:attribute>
        <xsl:apply-templates select="@source"/>
       </xsl:element>
      </xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="edit_element">
        <xsl:with-param name="id" select="@id"/>
        <xsl:with-param name="command" select="'set_source'"/>
        <xsl:with-param name="element" select="'span'"/>
        <xsl:with-param name="text" select="@source"/>
       </xsl:call-template>
      </xsl:otherwise>
     </xsl:choose>
     <p class="indent">
      Physical data source of this node. Formatted as a resource handler and name pair. The name
      is a unique indentifier, such as a USB serial number or file name.
     </p>
    </div>
   </xsl:if>

   <div class="row">
    <span class="title">
     <a name="gselect"><xsl:call-template name="kGSelect"/></a>
    </span>
    <xsl:choose>
     <xsl:when test="@connected=$True">
      <xsl:element name="span">
       <xsl:attribute name="class">read_only</xsl:attribute>
       <xsl:apply-templates select="@gselect"/>
      </xsl:element>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="edit_element">
       <xsl:with-param name="id" select="@id"/>
       <xsl:with-param name="command" select="'set_gselect'"/>
       <xsl:with-param name="text">
        <xsl:apply-templates select="@gselect"/>
       </xsl:with-param>
       <xsl:with-param name="class" select="'edit_float'"/>
       <xsl:with-param name="element" select="'span'"/>
       <xsl:with-param name="select">
        <xsl:text>[{value:2}</xsl:text>
        <xsl:choose>
         <xsl:when test="not(starts-with(@source,'usb://')) and @node_version&gt;10">
          <xsl:text>,{value:4}</xsl:text>
          <xsl:if test="@node_version&gt;12">
            <xsl:if test="@node_version&gt;13">
              <xsl:text>,{value:6}</xsl:text>
            </xsl:if>
            <xsl:text>,{value:8},{value:16}</xsl:text>
          </xsl:if>
         </xsl:when>
         <xsl:otherwise>
          <xsl:text>,{value:6}</xsl:text>
         </xsl:otherwise>
        </xsl:choose>
        <xsl:text>]</xsl:text>
       </xsl:with-param>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    <p class="indent">
     Range of the accelerometer specified in <em>g</em>. Selectable
     before a device is connected, the acceleration range is fixed for a session.
    </p>
   </div>

   <xsl:if test="@node_version&lt;10">
    <div class="row">
     <span class="title">
      <a name="time_step"><xsl:call-template name="kSampleRate"/></a>
     </span>
     <xsl:choose>
      <xsl:when test="@connected=$True">
       <xsl:element name="span">
        <xsl:attribute name="class">read_only</xsl:attribute>
        <xsl:apply-templates select="@time_step"/>
       </xsl:element>
      </xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="edit_element">
        <xsl:with-param name="id" select="@id"/>
        <xsl:with-param name="command" select="'set_time_step'"/>
        <xsl:with-param name="text" select="@time_step"/>
        <xsl:with-param name="class" select="'edit_float'"/>
        <xsl:with-param name="element" select="'span'"/>
        <xsl:with-param name="select">
         <xsl:text>[</xsl:text>
         <xsl:choose>
          <xsl:when test="@node_version&lt;10">
           <xsl:text>{value:50},{value:60},{value:70},{value:80},{value:90},{value:100}</xsl:text>
          </xsl:when>
          <xsl:otherwise>
           <xsl:text>{value:50},{value:60},{value:70},{value:80},{value:90},{value:100}</xsl:text>
          </xsl:otherwise>
         </xsl:choose>
         <xsl:text>]</xsl:text>
        </xsl:with-param>
       </xsl:call-template>
      </xsl:otherwise>
     </xsl:choose>
     <p class="indent">
      Sample rate specified in <em>hertz</em> (<em>Hz</em>) or number of samples per second.  Selectable
      before a device is connected, the sample rate is fixed for a session.
     </p>
    </div>
   </xsl:if>

   <div class="row">
    <span class="title">
     <a name="gain"><xsl:call-template name="kFilter"/></a>
    </span>
    <xsl:choose>
     <xsl:when test="/state/@taking=$True">
      <xsl:element name="span">
       <xsl:attribute name="class">read_only_float</xsl:attribute>
       <xsl:apply-templates select="@gain"/>
      </xsl:element>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="edit_element">
       <xsl:with-param name="id" select="@id"/>
       <xsl:with-param name="command" select="'set_gain'"/>
       <xsl:with-param name="text" select="@gain"/>
       <xsl:with-param name="element" select="'span'"/>
       <xsl:with-param name="class" select="'edit_float'"/>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    <p class="indent">
     Adjust the orientation filter smoothness. Unit parameter in range 0 to 1.
    </p>
    <p class="indent">
     0 denotes smoother output while 1 denotes more responsive output. The default
     value is 0.5 and is suitable for most applications.
    </p>
   </div>

   <div class="row">
    <span class="title">
     <a name="gain_sensor"><xsl:call-template name="kSensorGain"/></a>
    </span>
    <xsl:choose>
     <xsl:when test="/state/@taking=$True">
      <xsl:element name="span">
       <xsl:attribute name="class">read_only_float</xsl:attribute>
       <xsl:apply-templates select="@gain_sensor"/>
      </xsl:element>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="edit_element">
       <xsl:with-param name="id" select="@id"/>
       <xsl:with-param name="command" select="'set_gain_sensor'"/>
       <xsl:with-param name="text" select="@gain_sensor"/>
       <xsl:with-param name="element" select="'span'"/>
       <xsl:with-param name="class" select="'edit_float'"/>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    <p class="indent">
     Adjust independent sensor channel software smoothing. This parameter
     affects the calibrated sensor outputs but not the orientation outputs.
    </p>
    <p class="indent">Unit parameter in range 0 to 1.</p>
    <p class="indent">
     0 denotes smoother output while 1 denotes more responsive output. The default
     value is 1 which disables all software based smoothing.
    </p>
   </div>

   <div class="row">
    <span class="title">
     <a name="track_gyroscope_bias">
      <xsl:call-template name="kTrackGyroscopeBias"/>
     </a>
    </span>
    <xsl:choose>
     <xsl:when test="/state/@taking=$True">
      <xsl:element name="span">
       <xsl:attribute name="class">read_only_float</xsl:attribute>
       <xsl:apply-templates select="@track_gyroscope_bias"/>
      </xsl:element>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="edit_element">
       <xsl:with-param name="id" select="@id"/>
       <xsl:with-param name="command" select="'set_track_gyroscope_bias'"/>
       <xsl:with-param name="text" select="@track_gyroscope_bias"/>
       <xsl:with-param name="element" select="'span'"/>
       <xsl:with-param name="class" select="'edit_float'"/>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    <p class="indent">
     Adjust the gyroscope null bias tracking system. Handheld applications may require a larger
     value to more aggressively track the bias. Regular or machine based motions may require a smaller
     value (<em>~0.25</em>) to correctly track small angular rates.
    </p>
    <p class="indent">
     Unit parameter in range 0 to 1.
    </p>
    <p class="indent">
     1 denotes the most aggressive tracking. 0 denotes that bias tracking is disabled.
    </p>
   </div>

   <div class="row">
    <span class="title">
     <a name="pipeline_select">
      <xsl:call-template name="kPipelineSelect"/>
     </a>
    </span>

    <xsl:choose>
     <xsl:when test="/state/@taking=$True">
      <xsl:element name="span">
       <xsl:attribute name="class">read_only_float</xsl:attribute>
       <xsl:apply-templates select="@pipeline_select"/>
      </xsl:element>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="edit_element">
       <xsl:with-param name="id" select="@id"/>
       <xsl:with-param name="command" select="'set_pipeline_select'"/>
       <xsl:with-param name="text">
        <xsl:apply-templates select="@pipeline_select"/>
       </xsl:with-param>
       <xsl:with-param name="element" select="'span'"/>
       <xsl:with-param name="class" select="'edit_float'"/>
       <xsl:with-param name="select">
        <xsl:text>[{key:-1,value:'</xsl:text>
        <xsl:call-template name="kNone"/>
        <xsl:text>'},{key:0,value:'</xsl:text>
        <xsl:call-template name="kAll"/>
        <xsl:text>'},{key:1,value:'</xsl:text>
        <xsl:call-template name="kAccelerometer"/>
        <xsl:text>'},{key:4,value:'</xsl:text>
        <xsl:call-template name="kGyroscope"/>
        <xsl:text>'},{key:3,value:'</xsl:text>
        <xsl:call-template name="kAccelerometerMagnetometer"/>
        <xsl:text>'},{key:5,value:'</xsl:text>
        <xsl:call-template name="kAccelerometerGyroscope"/>
        <xsl:text>'}]</xsl:text>
       </xsl:with-param>
       <xsl:with-param name="select_key">
        <xsl:value-of select="floor(@pipeline_select)"/>
       </xsl:with-param>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    <p class="indent">
     Select orientation pipeline by sensor inputs.
    </p>
   </div>

  </div>
 </xsl:template>

 <xsl:template match="take">
  <xsl:element name="a">
   <xsl:attribute name="title">
    <xsl:call-template name="kViewCurrentTake"/>
   </xsl:attribute>
   <xsl:attribute name="onclick">
    <xsl:text>javascript:GLI_EventListener.stop(event);</xsl:text>
   </xsl:attribute>
   <xsl:choose>
    <xsl:when test="string-length(@loaded_from)&gt;0">
     <xsl:attribute name="href">
      <xsl:value-of select="$BaseDataURL"/>
      <xsl:value-of select="@loaded_from"/>
     </xsl:attribute>
    </xsl:when>
    <xsl:otherwise>
     <xsl:attribute name="style">
      <xsl:text>color: #676767; text-decoration: underline;</xsl:text>
     </xsl:attribute>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:call-template name="kCurrentTake"/>
  </xsl:element>
 </xsl:template>

 <!-- Map drop down list names to text values. -->
 <xsl:template match="@pipeline_select[.=-1]">
  <xsl:call-template name="kNone"/>
 </xsl:template>
 <xsl:template match="@pipeline_select[.=0]">
  <xsl:call-template name="kAll"/>
 </xsl:template>
 <xsl:template match="@pipeline_select[.=1]">
  <xsl:call-template name="kAccelerometer"/>
 </xsl:template>
 <xsl:template match="@pipeline_select[.=4]">
  <xsl:call-template name="kGyroscope"/>
 </xsl:template>
 <xsl:template match="@pipeline_select[.=3]">
  <xsl:call-template name="kAccelerometerMagnetometer"/>
 </xsl:template>
 <xsl:template match="@pipeline_select[.=5]">
  <xsl:call-template name="kAccelerometerGyroscope"/>
 </xsl:template>

 <xsl:template match="@gselect">
  <xsl:value-of select="floor(.)"/>
 </xsl:template>

</xsl:stylesheet>
