<?xml version="1.0"?>
<!--
XSL transformation to convert a COLLADA file (http://www.collada.org/) to a
Motion Service Configuration file.

Expects the following <dae:node> format:
  <node id="jointName" name="jointName" type="JOINT">
   <translate sid="translate">0 0 0</translate>
   <rotate sid="jointOrientZ">0 0 1 0</rotate>
   <rotate sid="jointOrientY">0 1 0 0</rotate>
   <rotate sid="jointOrientX">1 0 0 0</rotate>
   ... <node/>
  </node>
  
Note that the sid attribute is used to determine transformation order so it is
required for this conversion to work.
 
@file    static/style/transform/collada_to_node.xsl
@author  Luke Tokheim, luke@motionnode.com
@version 2.0

(C) Copyright GLI Interactive LLC 2012. All rights reserved.

Permission is hereby granted, free of charge, to any person or organization
obtaining a copy of the software and accompanying documentation covered by
this license (the "Software") to use, reproduce, display, distribute,
execute, and transmit the Software, and to prepare derivative works of the
Software, and to permit third-parties to whom the Software is furnished to
do so, all subject to the following:

The copyright notices in the Software and this entire statement, including
the above license grant, this restriction and the following disclaimer,
must be included in all copies of the Software, in whole or in part, and
all derivative works of the Software, unless such copies or derivative
works are solely in the form of machine-executable object code generated by
a source language processor.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
-->
<xsl:stylesheet
  version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:dae="http://www.collada.org/2005/11/COLLADASchema"
  xmlns:str="http://xsltsl.org/string">

 <!-- XML output. -->
 <xsl:output
   encoding="utf-8" 
   indent="yes" 
   method="xml"
   omit-xml-declaration="no"
   version="1.0"/>

 <!-- Strip all whitespace. -->
 <xsl:strip-space elements="*"/>

 <!-- Squash all nodes by default. -->
 <xsl:template match="*"/>

 <!-- COLLADA root element. -->
 <xsl:template match="/dae:COLLADA">
  <xsl:element name="node">
   <xsl:attribute name="id">
    <xsl:text>default</xsl:text>
   </xsl:attribute> 
   <xsl:apply-templates select="dae:library_visual_scenes/dae:visual_scene/dae:node"/>
  </xsl:element>
 </xsl:template>

 <!-- Joint node rule. [@type='JOINT'] -->
 <xsl:template match="dae:node">
  <xsl:element name="node">
   <xsl:attribute name="id">
    <xsl:value-of select="@id"/>
   </xsl:attribute>
   <xsl:attribute name="name">
    <xsl:value-of select="@name"/>
   </xsl:attribute>
   <xsl:apply-templates select="dae:translate[@sid='translate']"/>
   <xsl:attribute name="rotate">
    <xsl:call-template name="axis_angle_channel">
     <xsl:with-param name="value">
      <xsl:apply-templates select="dae:rotate[@sid='jointOrientX']"/>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:text> </xsl:text>
    <xsl:call-template name="axis_angle_channel">
     <xsl:with-param name="value">
      <xsl:apply-templates select="dae:rotate[@sid='jointOrientY']"/>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:text> </xsl:text>
    <xsl:call-template name="axis_angle_channel">
     <xsl:with-param name="value">
      <xsl:apply-templates select="dae:rotate[@sid='jointOrientZ']"/>
     </xsl:with-param>
    </xsl:call-template>
   </xsl:attribute>
   <xsl:apply-templates select="dae:node"/>
  </xsl:element>
 </xsl:template>
 
 <!-- Rotate, output text value. -->
 <xsl:template match="dae:rotate">
  <xsl:apply-templates/>
 </xsl:template>

 <!-- Translate, copy a node into an attribute. -->
 <xsl:template match="dae:translate">
  <xsl:attribute name="translate">
   <xsl:apply-templates/>
  </xsl:attribute>
 </xsl:template>

 <!--
 Return the rotation angle value from a COLLADA axis-angle
 rotate element.
 -->
 <xsl:template name="axis_angle_channel">
  <xsl:param name="value"/>
  
  <xsl:call-template name="array_random_access">
   <xsl:with-param name="index" select="3"/>
   <xsl:with-param name="array" select="$value"/>
   <xsl:with-param name="default" select="0"/>
  </xsl:call-template> 
 </xsl:template>
 
 <!--
 Implement random access for a COLLADA array. For example,
 if x = "1.1 9.2 6.8" then x[0] = 1.1, x[1] = 9.2, and
 x[2] = 6.8. Use this to grab single elements from an array
 of data.
  
 Example:
   <xsl:call-template name="array_random_access">
    <xsl:with-param name="index" select="2"/>
    <xsl:with-param name="array" select="'1.1 9.2 6.8 4.2'">
   </xsl:call-template>
  
 Produces output "6.8". If the item is not found, then
 return the "default" value.
 -->
 <xsl:template name="array_random_access">
  <xsl:param name="array"/>
  <xsl:param name="default" select="0"/>
  <xsl:param name="index" select="0"/>
  
  <xsl:variable name="result">
   <xsl:call-template name="str:substring-after-at">
    <xsl:with-param name="text" select="$array"/>
    <xsl:with-param name="chars" select="' '"/>
    <xsl:with-param name="position" select="$index"/>
   </xsl:call-template>
  </xsl:variable>
  
  <xsl:choose>
   <xsl:when test="string-length($result)=0">
    <xsl:value-of select="$default"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$result"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>


 <!--
 The following function was taken from the XSLT Standard Library
 available at: http://xsltsl.sourceforge.net/.
  
 It can be removed if you want to use a newer version of the XSLTSL
 library. I believe this is adheres to the LGPL license of the XSLT
 Standard Library.
 -->
 <xsl:template name="str:substring-after-at">
  <xsl:param name="text"/>
  <xsl:param name="chars"/>
  <xsl:param name="position"/>
  <xsl:param name="all" select='false()'/>

  <xsl:choose>

   <xsl:when test='number($position) = 0 and $all'>
    <xsl:value-of select='$text'/>
   </xsl:when>
   <xsl:when test='number($position) = 0 and not($chars)'>
    <xsl:value-of select='$text'/>
   </xsl:when>
   <xsl:when test='number($position) = 0 and not(contains($text, $chars))'>
    <xsl:value-of select='$text'/>
   </xsl:when>

   <xsl:when test='not(contains($text, $chars))'>
   </xsl:when>
   <xsl:when test="number($position) = 0">
    <xsl:value-of select="substring-before($text, $chars)"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="str:substring-after-at">
     <xsl:with-param name="text" select="substring-after($text, $chars)"/>
     <xsl:with-param name="chars" select="$chars"/>

     <xsl:with-param name="all" select="$all"/>
     <xsl:with-param name="position" select="$position - 1"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

</xsl:stylesheet>
 