<?xml version="1.0"?>
<!--
 Convert and XML Configurable service request into a flat list of channels for
 easy parsing. Implements the grouping rules for the data channels.

 @file    static/style/transform/configurable.xsl
 @version 2.4
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:output method="text"/>

 <xsl:strip-space elements="*"/>

 <xsl:variable name="Separator">
  <xsl:text> </xsl:text>
 </xsl:variable>

 <!-- Print a channel with child names, like x, y, z. -->
 <xsl:template name="enumerate_channel">
  <xsl:param name="name"/>
  <xsl:param name="dim4"/>

  <xsl:if test="$dim4">
   <xsl:value-of select="$name"/>
   <xsl:text>w</xsl:text>
   <xsl:value-of select="$Separator"/>
  </xsl:if>
  <xsl:value-of select="$name"/>
  <xsl:text>x</xsl:text>
  <xsl:value-of select="$Separator"/>
  <xsl:value-of select="$name"/>
  <xsl:text>y</xsl:text>
  <xsl:value-of select="$Separator"/>
  <xsl:value-of select="$name"/>
  <xsl:text>z</xsl:text>
  <xsl:value-of select="$Separator"/>
 </xsl:template>

 <!-- Allow all nodes by default. -->
 <xsl:template match="*">
  <xsl:apply-templates/>
 </xsl:template>

 <!-- Preview data stream. -->
 <xsl:template name="preview_stream">
  <xsl:choose>
   <xsl:when test="count(*)&gt;0">
    <xsl:apply-templates select="Gq|Gdq|Lq|r|la|lv|lt|c|Gqw|Gqx|Gqy|Gqz|Gdqw|Gdqx|Gdqy|Gdqz|Lqw|Lqx|Lqy|Lqz|rx|ry|rz|lax|lay|laz|lvx|lvy|lvz|ltx|lty|ltz|cw|cx|cy|cz"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>Gq</xsl:text>
     </xsl:with-param>
     <xsl:with-param name="dim4">
      <xsl:text>1</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>Gdq</xsl:text>
     </xsl:with-param>
     <xsl:with-param name="dim4">
      <xsl:text>1</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>Lq</xsl:text>
     </xsl:with-param>
     <xsl:with-param name="dim4">
      <xsl:text>1</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>r</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>la</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>lv</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>lt</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>c</xsl:text>
     </xsl:with-param>
     <xsl:with-param name="dim4">
      <xsl:text>1</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <!-- Sensor data stream. -->
 <xsl:template name="sensor_stream">
  <xsl:choose>
   <xsl:when test="count(*)&gt;0">
    <xsl:apply-templates select="a|m|g|ax|ay|az|mx|my|mz|gx|gy|gz|temp"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>a</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>m</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>g</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:text>temp</xsl:text>
    <xsl:value-of select="$Separator"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <!-- Raw data stream. -->
 <xsl:template name="raw_stream">
  <xsl:choose>
   <xsl:when test="count(*)&gt;0">
    <xsl:apply-templates select="A|M|G|Ax|Ay|Az|Mx|My|Mz|Gx|Gy|Gz|Temp"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>A</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>M</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="enumerate_channel">
     <xsl:with-param name="name">
      <xsl:text>G</xsl:text>
     </xsl:with-param>
    </xsl:call-template>
    <xsl:text>Temp</xsl:text>
    <xsl:value-of select="$Separator"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <!-- Time data stream. -->
 <xsl:template name="time_stream">
  <xsl:choose>
   <xsl:when test="count(*)&gt;0">
    <xsl:apply-templates select="dt|timestamp|systemtime"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>dt</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:text>timestamp</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:text>systemtime</xsl:text>
    <xsl:value-of select="$Separator"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <!-- Error data stream. -->
 <xsl:template name="error_stream">
  <xsl:choose>
   <xsl:when test="count(*)&gt;0">
    <xsl:apply-templates select="ea|em|eg|eq|ec"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>ea</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:text>em</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:text>eg</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:text>eq</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:text>ec</xsl:text>
    <xsl:value-of select="$Separator"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <!--
  Bus data stream. Not associated with a single node. A frame of N bundled nodes
  has one shared bus entry.
 -->
 <xsl:template name="bus_stream">
  <xsl:choose>
   <xsl:when test="count(*)&gt;0">
    <xsl:apply-templates select="p|atm|elev|pw|px|py|pz"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="enumerate_channel">
      <xsl:with-param name="name">
        <xsl:text>p</xsl:text>
      </xsl:with-param>
      <xsl:with-param name="dim4">
        <xsl:text>1</xsl:text>
      </xsl:with-param>
    </xsl:call-template>
    <xsl:text>atm</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:text>elev</xsl:text>
    <xsl:value-of select="$Separator"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="all">
  <xsl:choose>
   <xsl:when test="count(*)&gt;0">
    <xsl:apply-templates/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="preview_stream"/>
    <xsl:call-template name="sensor_stream"/>
    <xsl:call-template name="raw_stream"/>
    <xsl:call-template name="time_stream"/>
    <xsl:call-template name="error_stream"/>
    <xsl:call-template name="bus_stream"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="preview">
  <xsl:call-template name="preview_stream"/>
 </xsl:template>

 <xsl:template match="sensor">
  <xsl:call-template name="sensor_stream"/>
 </xsl:template>

 <xsl:template match="raw">
  <xsl:call-template name="raw_stream"/>
 </xsl:template>

 <xsl:template match="time">
  <xsl:call-template name="time_stream"/>
 </xsl:template>

 <xsl:template match="error">
  <xsl:call-template name="error_stream"/>
 </xsl:template>

 <xsl:template match="bus">
  <xsl:call-template name="bus_stream"/>
 </xsl:template>

 <!-- Quaternion, vector with weight channel, and four element vector. -->
 <xsl:template match="Gq|Gdq|Lq|c|p">
  <xsl:choose>
   <xsl:when test="count(*)&gt;0">
    <xsl:for-each select="w|x|y|z">
     <xsl:value-of select="name(parent::node())"/>
     <xsl:value-of select="name()"/>
     <xsl:value-of select="$Separator"/>
    </xsl:for-each>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="name()"/>
    <xsl:text>w</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:value-of select="name()"/>
    <xsl:text>x</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:value-of select="name()"/>
    <xsl:text>y</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:value-of select="name()"/>
    <xsl:text>z</xsl:text>
    <xsl:value-of select="$Separator"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <!-- Three element vector channel. -->
 <xsl:template match="r|la|lv|lt|a|m|g|A|M|G">
  <xsl:choose>
   <xsl:when test="count(*)&gt;0">
    <xsl:for-each select="x|y|z">
     <xsl:value-of select="name(parent::node())"/>
     <xsl:value-of select="name()"/>
     <xsl:value-of select="$Separator"/>
    </xsl:for-each>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="name()"/>
    <xsl:text>x</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:value-of select="name()"/>
    <xsl:text>y</xsl:text>
    <xsl:value-of select="$Separator"/>
    <xsl:value-of select="name()"/>
    <xsl:text>z</xsl:text>
    <xsl:value-of select="$Separator"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <!-- Scalar channel. Also enumerate all possible channels here. -->
 <xsl:template match="Gqw|Gqx|Gqy|Gqz|Gdqw|Gdqx|Gdqy|Gdqz|Lqw|Lqx|Lqy|Lqz|rx|ry|rz|lax|lay|laz|lvx|lvy|lvz|ltx|lty|ltz|cw|cx|cy|cz|ax|ay|az|mx|my|mz|gx|gy|gz|temp|Ax|Ay|az|Mx|My|Mz|Gx|Gy|Gz|Temp|dt|timestamp|systemtime|ea|em|eg|eq|ec|pw|px|py|pz|atm|elev">
  <xsl:value-of select="name()"/>
  <xsl:value-of select="$Separator"/>
 </xsl:template>

</xsl:stylesheet>