<?xml version="1.0"?>
<!--
  Generate the "initialize.lua" file from the user initialization
  source XML file.

  @file    static/style/transform/initialize_to_lua.xsl
  @version 2.5
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:output method="text"/>

 <xsl:template match="*"/>

 <xsl:template match="/">
  <xsl:apply-templates select="initialize"/>
 </xsl:template>

 <xsl:template match="initialize[@valid='true']">
  <xsl:text>--
-- The "bootstrap.lua" file calls this script at start up. Define all
-- site specific preferences in this file.
--
-- Generated by the "static/xsl/t/initialize_to_lua.xsl"
-- style sheet.
--
-- @file    initialize.lua
-- @version 2.5
--

</xsl:text>

  <!-- Data path. The other file writing commands (i.e. the log file) depend on
  this path, so do it first. -->
  <xsl:text>
local result, message

</xsl:text>
  <xsl:text>
--
-- Check if the system is already initialized. If it is simply
-- return now.
--
if node.system.is_initialized() then
  return
end

</xsl:text>
  <xsl:if test="string-length(data_path/text())&gt;0">
   <xsl:text>
--
-- Set the output (and search) path for writable data.
-- Examples:
--  "data", "c:/data", "//network_name/data", or "H:\\Take Data"
--

result, message = node.system.set_data_path("</xsl:text>

   <xsl:choose>
    <xsl:when test="string-length(data_path/text())&gt;0">
     <xsl:apply-templates select="data_path/text()"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:text>data</xsl:text>
    </xsl:otherwise>
   </xsl:choose>

   <xsl:text>")
if not result then
  error(message)
end

</xsl:text>
  </xsl:if>

  <!-- Log file. Defaults to "log.xml" in the data path root. -->
  <xsl:text>
--
-- Set the system wide log file name.
--
result, message = node.system.log("</xsl:text>

  <xsl:choose>
   <xsl:when test="string-length(log_path/text())&gt;0">
    <xsl:apply-templates select="log_path/text()"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>default/log.xml</xsl:text>
   </xsl:otherwise>
  </xsl:choose>

  <xsl:text>")
if not result then
  error(message)
end

</xsl:text>

  <!-- Open a database file. Optional. -->
  <xsl:text>
--
-- Open default database file.
--
if node.system.file_exists("default/database.db") then
  node.system.open_database("default/database.db")
end

</xsl:text>

  <!-- Define which plugins to load at initialization time.  -->
  <xsl:text>
--
-- Load all plugins in the search path.
--
node.system.load_plugin()

</xsl:text>

  <!-- Define which services to run and which ports to listen on. -->
  <xsl:text>
--
-- Define and start services.
--
local service = {
  -- Switchboard for monitor and other data stream services.
  ["monitor"] = 32074,
  -- Interactive console service, optional.
  ["console"] = 32075,
  -- Provide real-time access to all Node data. The
  -- client requests the channels that it wants.
  ["device_configurable"] = 32076,
  -- Provide real-time access to the raw Node data.
  ["device_raw"] = 32077,
  -- Provide real-time access to the calibrated Node data.
  ["device_sensor"] = 32078,
  -- Provide real-time access to the Node filter orientation
  -- output in multiple formats.
  ["device_preview"] = 32079,
  -- Accept HTTP connections. Required for the web based
  -- user interface.
  ["http"] = 32080
}

--
-- If we failed to start any of the requested services
-- call it a fatal error.
--
result, message = node.system.start_services(service)
if not result then
  error(message)
end

</xsl:text>

  <!-- Site location. Critical preference for accurate magnetometer data. -->
  <xsl:text>
--
-- Set the current geographic location. This is required to compute the
-- geomagnetic field reference value. Note that the "location.mGeocode" file
-- will override the location entered in this file.
--

</xsl:text>

  <xsl:if test="string-length(address/canonical/text())&gt;0">
   <xsl:text>--
-- Location address.
-- </xsl:text>
   <xsl:apply-templates select="address/canonical/text()"/>
   <xsl:text>
--
</xsl:text>
  </xsl:if>

  <xsl:text>
-- Decimal degrees (-90, 90) where negative latitude denotes Southern hemisphere
local latitude = </xsl:text>

  <xsl:choose>
   <xsl:when test="string-length(location/latitude/text())&gt;0">
    <xsl:apply-templates select="location/latitude/text()"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>38</xsl:text>
   </xsl:otherwise>
  </xsl:choose>

  <xsl:text>
-- Decimal degrees (-180, 180) where negative longitude denotes Western hemisphere
local longitude = </xsl:text>

  <xsl:choose>
   <xsl:when test="string-length(location/longitude/text())&gt;0">
    <xsl:apply-templates select="location/longitude/text()"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>-97</xsl:text>
   </xsl:otherwise>
  </xsl:choose>

  <xsl:text>
-- Elevation from surface of earth in Meters, [-1000, 600000]
local elevation = </xsl:text>

  <xsl:choose>
   <xsl:when test="string-length(location/elevation/text())&gt;0">
    <xsl:apply-templates select="location/elevation/text()"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>0</xsl:text>
   </xsl:otherwise>
  </xsl:choose>

  <xsl:text>
-- Street address. Just informative.
local street_address = "</xsl:text>

  <xsl:choose>
   <xsl:when test="string-length(address/canonical/text())&gt;0">
    <xsl:apply-templates select="address/canonical/text()"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text></xsl:text>
   </xsl:otherwise>
  </xsl:choose>

  <xsl:text>"</xsl:text>

  <xsl:text>

</xsl:text>

  <!-- Load the default location file. Optional. -->
  <xsl:text>
--
-- Load default location file.
--
if node.system.file_exists(node._location_filename) and node.open(node._location_filename) then
else
  -- Check if we already have a geographic location loaded from the database or
  -- other command.
  local preference = node.system.get_preference()
  if not preference or 0 == preference.location.active then
    result, message = node.system.location(latitude, longitude, elevation, street_address)
    if not result then
      error(message)
    end
  end
end

</xsl:text>

  <!-- Load the default ractor file. Optional. -->
  <xsl:text>
--
-- Load default ractor file.
--
if node.system.file_exists(node._ractor_filename) then
  node.open(node._ractor_filename)
end

</xsl:text>

  <!-- Load the default configuration file. Optional. -->
  <xsl:text>
--
-- Load default configuration file.
--
if node.system.file_exists(node._configuration_filename) then
  node.open(node._configuration_filename)
end

</xsl:text>

  <!-- Scan for available devices if the configuration is empty. Optional. -->
  <xsl:text>
--
-- Scan for available devices if the configuration is empty.
--
if not node.is_configured() then
  node.scan()
end

</xsl:text>

  <!-- Run a user initialization script. Optional. -->
  <xsl:text>
--
-- Run user start up script.
--
if node.system.file_exists("default/user.lua") then
  node.open("default/user.lua")
end
</xsl:text>

  <!-- Start reading from all configured devices. -->
  <xsl:text>
--
-- Start reading from all configured devices.
--
if node._BUS and node.is_configured() then
  node.start()
end
</xsl:text>

  <xsl:text>
--
-- End initialize.lua
--
</xsl:text>
 </xsl:template>

</xsl:stylesheet>
