<?xml version="1.0"?>
<!--
 @file   static/style/transform/node_merge.xsl
 @brief  Combine two configuration files into one. Use the hierarchy and rest
         pose information from one and the hardware channel associations from
         the other. The service uses this to enumerate a set of nodes on a
         Shadow system and generate a hierarchy on the fly.
-->
<xsl:stylesheet
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 version="1.0">

 <xsl:output encoding="utf-8" indent="yes" method="xml"/>

 <xsl:param name="host">
  <xsl:text>Shadow</xsl:text>
 </xsl:param>
 <xsl:param name="name">
  <xsl:text>bus://</xsl:text>
  <xsl:value-of select="$host"/>
 </xsl:param>
 <xsl:param name="tree">
  <xsl:text>definition.xml</xsl:text>
 </xsl:param>

 <!-- Shadow skeleton joint names for matching. -->
 <xsl:param name="Body">
  <xsl:text>Body</xsl:text>
 </xsl:param>
  <xsl:param name="Hips">
  <xsl:text>Hips</xsl:text>
 </xsl:param>
 <xsl:param name="SpineLow">
  <xsl:text>SpineLow</xsl:text>
 </xsl:param>
 <xsl:param name="Chest">
  <xsl:text>Chest</xsl:text>
 </xsl:param>
 <xsl:param name="LeftThigh">
  <xsl:text>LeftThigh</xsl:text>
 </xsl:param>
 <xsl:param name="LFP">
  <xsl:text>LFP</xsl:text>
 </xsl:param>
 <xsl:param name="RFP">
  <xsl:text>RFP</xsl:text>
 </xsl:param>

 <xsl:variable name="src" select="document($tree)"/>
 <xsl:variable name="tgt" select="/"/>

 <!-- Strip all whitespace. -->
 <xsl:strip-space elements="*"/>

 <!-- Squash all nodes by default. -->
 <xsl:template match="*"/>

 <xsl:template match="/node">
  <xsl:variable name="id" select="$Body"/>
 
  <xsl:element name="node">
   <xsl:attribute name="id">
    <xsl:text>default</xsl:text>
   </xsl:attribute>

   <xsl:if test="node[@id=$id and @source=$name]">
    <xsl:apply-templates select="$src/node/node[@id=$id]" mode="tree"/>
   </xsl:if>
   <xsl:apply-templates select="node" mode="scan"/>
  </xsl:element>
 </xsl:template>

 <xsl:template match="node" mode="tree">
  <xsl:element name="node">
   <xsl:variable name="id" select="@id"/>
   <xsl:variable
    name="source"
    select="$tgt/node//node[@id=$id]/@source"/>

   <xsl:attribute name="id">
    <xsl:value-of select="$id"/>
   </xsl:attribute>

   <xsl:if test="string-length($source)">
    <xsl:attribute name="source">
     <xsl:value-of select="$source"/>
    </xsl:attribute>
   </xsl:if>

   <xsl:copy-of select="@rotate|@translate|@marker|@mass"/>

   <!-- Copy other properties from the node enumeration. -->
   <xsl:apply-templates
    select="$tgt/node//node[@id=$id]"
    mode="source"/>

   <!-- Mark node as not active if there is not source attribute. -->
   <xsl:if test="not(string-length($source))">
    <xsl:attribute name="active">
     <xsl:text>0</xsl:text>
    </xsl:attribute>
   </xsl:if>

   <xsl:if test="starts-with($id,$LFP) or starts-with($id,$RFP)">
    <xsl:attribute name="pipeline_select">
     <xsl:text>-1</xsl:text>
    </xsl:attribute>
   </xsl:if>

	  <!-- Filter out subtrees for the Shadow upper and lower body systems. -->
   <xsl:choose>
    <xsl:when test="(starts-with($id,$Body) or starts-with($id,$Hips)) and
                    not($tgt/node//node[starts-with(@id,$LeftThigh)])">
   	 <xsl:apply-templates
      select="node[starts-with(@id,$Hips) or starts-with(@id,$SpineLow)]"
      mode="tree"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:if test="not(starts-with($id,$SpineLow)) or
                   $tgt/node//node[starts-with(@id,$Chest)]">
      <xsl:apply-templates select="node" mode="tree"/>
     </xsl:if>
    </xsl:otherwise>
   </xsl:choose>

  </xsl:element>
 </xsl:template>

 <!--
 	Copy a tree of nodes from the configuration or scan results without changing
  the hierarchy.
 -->
 <xsl:template match="node" mode="scan">
  <xsl:variable name="id" select="@id"/>
 	<xsl:if test="not($src/node//node[@id=$id])">
   <xsl:element name="node">
    <xsl:copy-of select="@*"/>
    <xsl:apply-templates select="node" mode="scan"/>
    </xsl:element>
  </xsl:if>
 </xsl:template>

 <!-- Copy attributes from the scan result node. -->
 <xsl:template match="node" mode="source">
  <xsl:copy-of select="@gselect|@bus|@parent"/>
 </xsl:template>

</xsl:stylesheet>
