<?xml version="1.0"?>
<!--
 @file   static/style/transform/node_to_mvc.xsl
 @brief  Mokka Model Configuration File (*.mvc). Defines links in the skeleton
         for the Mokka 3D kinematic motion viewer.
-->
<xsl:stylesheet
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 version="1.0">

 <!-- XML output -->
 <xsl:output method="xml" indent="yes"/>

 <!-- Strip all whitespace. -->
 <xsl:strip-space elements="*"/>

 <!-- Squash all nodes by default. -->
 <xsl:template match="*"/>

 <xsl:template match="/">
  <MokkaModelVisualConfiguration name="Shadow" version="1.0">
   <xsl:element name="MarkersList">
    <xsl:apply-templates select="node//node" mode="marker"/>
   </xsl:element>
   <xsl:element name="SegmentsList">
    <Segment label="Shadow">
     <xsl:apply-templates select="node//node" mode="point"/>
     <xsl:apply-templates select="node//node[starts-with(@id,'Hips')]//node" mode="segment"/>
    </Segment>
   </xsl:element>
  </MokkaModelVisualConfiguration>
 </xsl:template>

 <xsl:template match="node" mode="marker">
  <xsl:element name="Marker">
   <xsl:attribute name="label">
    <xsl:value-of select="@id"/>
   </xsl:attribute>
   <xsl:if test="starts-with(@id,'LFP') or starts-with(@id,'RFP')">
    <xsl:attribute name="visible">
     <xsl:text>0</xsl:text>
    </xsl:attribute>
    <xsl:attribute name="description">
     <xsl:text>Pressure sensor markers values, not a position.</xsl:text>
    </xsl:attribute>
   </xsl:if>
   <xsl:attribute name="description">
    <xsl:call-template name="marker_desc">
     <xsl:with-param name="id" select="@id"/>
    </xsl:call-template>
   </xsl:attribute>
  </xsl:element>
 </xsl:template>

 <xsl:template match="node" mode="point">
  <xsl:element name="Point">
   <xsl:attribute name="label">
    <xsl:value-of select="@id"/>
   </xsl:attribute>
  </xsl:element>
 </xsl:template>

 <xsl:template match="node[starts-with(@id,'Body') or starts-with(@id,'LFP') or starts-with(@id,'RFP')]" mode="point">
 </xsl:template>

 <xsl:template match="node" mode="segment">
  <xsl:element name="Link">
   <xsl:attribute name="pt1">
    <xsl:value-of select="../@id"/>
   </xsl:attribute>
   <xsl:attribute name="pt2">
    <xsl:value-of select="@id"/>
   </xsl:attribute>
  </xsl:element>
 </xsl:template>

 <xsl:template match="node[starts-with(@id,'Hips') or @name='Hips']" mode="segment">
 </xsl:template>

 <xsl:template name="marker_desc">
  <xsl:param name="id"/>

  <xsl:if test="starts-with($id,'Body')">
   <xsl:value-of select="$id"/>
  </xsl:if>
 </xsl:template>
</xsl:stylesheet>
