<?xml version="1.0"?>
<!--
  Generate a sequence of SQL statements to create a take entry
  in the database. Assumes that the sequence is wrapped in an
  exclusive transaction.
  
  Input parameter "path" defines the path this take was loaded
  from.
  Input parameter "location_match_distance" defines the minimum
  distance for the location equality comparison.

  @file    static/style/transform/take_to_sqlite.xsl
  @version 2.0
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:output method="text"/>

 <xsl:strip-space elements="*"/>

 <xsl:param name="path"/>
 <xsl:param name="take_path">
  <xsl:text>take.xml</xsl:text>
 </xsl:param>
 <xsl:param name="location_match_distance">
  <xsl:text>1000</xsl:text>
 </xsl:param>

 <xsl:template name="Insert">
  <xsl:param name="table">
   <xsl:value-of select="name()"/>
  </xsl:param>
  
  <xsl:text>INSERT OR ROLLBACK INTO </xsl:text>
  <xsl:value-of select="$table"/>
  <xsl:text> (</xsl:text>
 </xsl:template>
 
 <xsl:template match="*"/>
 <xsl:template match="*" mode="key"/>
 <xsl:template match="*" mode="value"/>

 <xsl:template match="/">
  <xsl:apply-templates select="boost_serialization"/>
 </xsl:template>

 <xsl:template match="boost_serialization[@signature='serialization::archive' and (@version='4' or @version='5')]">
  <xsl:text>-- BEGIN EXCLUSIVE TRANSACTION;
</xsl:text>
  <xsl:apply-templates select="take"/>
  <xsl:text>-- END TRANSACTION;
</xsl:text> 
 </xsl:template>

 <xsl:template match="take">
  <xsl:apply-templates select="location"/>

  <xsl:call-template name="Insert">
   <xsl:with-param name="table">
    <xsl:text>take</xsl:text>
   </xsl:with-param>
  </xsl:call-template>
  
  <xsl:apply-templates mode="key"/>
  <xsl:text>take_path,path,location_key,key) SELECT </xsl:text>
  <xsl:apply-templates mode="value"/>
  <xsl:text>"</xsl:text>
  <xsl:value-of select="$take_path"/>
  <xsl:text>","</xsl:text>
  <xsl:value-of select="$path"/>
  <xsl:text>",location.key,NULL FROM location</xsl:text>
  <xsl:text> WHERE LOCATION_EQUIVALENT(latitude,longitude,</xsl:text>
  <xsl:value-of select="location/item[1]"/>
  <xsl:text>,</xsl:text>
  <xsl:value-of select="location/item[2]"/>
  <xsl:text>);
</xsl:text>
  <xsl:apply-templates select="channel_list"/>
 </xsl:template>

 <xsl:template match="channel_list">
  <xsl:for-each select="item/second">
   <xsl:call-template name="Insert">
    <xsl:with-param name="table">
     <xsl:text>take_channel</xsl:text>
    </xsl:with-param>
   </xsl:call-template>
   <xsl:apply-templates mode="key"/>
   <xsl:text>node_key,take_key,key) SELECT </xsl:text>
   <xsl:apply-templates mode="value"/>
   <xsl:text>node.key,SQLITE_SEQUENCE.seq,NULL FROM SQLITE_SEQUENCE,node WHERE SQLITE_SEQUENCE.name="take" AND node.source="</xsl:text>
   <xsl:value-of select="source"/>
   <xsl:text>";
</xsl:text>
   <xsl:apply-templates/>
  </xsl:for-each>
 </xsl:template>

 <xsl:template match="raw|sensor|output">
  <xsl:call-template name="Insert">
   <xsl:with-param name="table">
    <xsl:text>take_channel_data</xsl:text>
   </xsl:with-param>
  </xsl:call-template>
  <xsl:apply-templates mode="key"/>
  <xsl:text>take_channel_key,take_channel_data_type_key,key) SELECT </xsl:text>
  <xsl:apply-templates mode="value"/>
  <xsl:text>SQLITE_SEQUENCE.seq,take_channel_data_type.key,NULL FROM SQLITE_SEQUENCE,take_channel_data_type</xsl:text>
  <xsl:text> WHERE SQLITE_SEQUENCE.name="take_channel" AND take_channel_data_type.name="</xsl:text>
  <xsl:value-of select="name()"/>
  <xsl:text>";
</xsl:text>
  <xsl:apply-templates/>
 </xsl:template>

 <xsl:template match="active|id|configuration_path|description|end|filename|name|path|sample|source|start" mode="key">
  <xsl:value-of select="name()"/>
  <xsl:text>,</xsl:text>
 </xsl:template>

 <xsl:template match="geomagnetic|location" mode="key">
  <xsl:for-each select="item">
   <xsl:value-of select="name(parent::node())"/>
   <xsl:value-of select="position()"/>
   <xsl:text>,</xsl:text>
  </xsl:for-each>
 </xsl:template>

 <xsl:template match="active|id|configuration_path|description|end|filename|name|path|sample|source|start" mode="value">
  <xsl:text>"</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>",</xsl:text>
 </xsl:template>

 <xsl:template match="geomagnetic|location" mode="value">
  <xsl:for-each select="item">
   <xsl:apply-templates/>
   <xsl:text>,</xsl:text>
  </xsl:for-each>
 </xsl:template>

 <xsl:template match="iso_extended">
  <xsl:apply-templates/>
 </xsl:template>
 
 <xsl:template match="string">
  <xsl:apply-templates/>
 </xsl:template>

 <!--
 <xsl:template match="raw/active|raw/end|raw/start|raw/sample|sensor/end|sensor/start|sensor/sample|output/start" mode="value">
  <xsl:apply-templates/>
  <xsl:text>,</xsl:text>
 </xsl:template>
 -->
 
</xsl:stylesheet>