<?xml version="1.0"?>
<!--
  Create an HTML version of the Motion Service take file format.

  @file    static/style/take.xsl
  @author  Luke Tokheim, luke@motionnode.com
  @version 2.0
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:import href="common.xsl"/>
  <xsl:template name="Title">
   <xsl:call-template name="kTake"/>
  </xsl:template>

  <xsl:template name="JavascriptShortcut">
    <xsl:text>[</xsl:text>
    <xsl:text>{command:'open', name:'Load Take', active:true, key: 'L', argument: this_uri()}</xsl:text>
    <xsl:text>,{command:'load_take_source', name:'Load Take Source', active:true, key: 'S', argument: this_uri()}</xsl:text>
    <xsl:text>,{command:'track_take', name:'Track Take', active:true, key: 'T', argument: this_uri()}</xsl:text>
    <xsl:text>]</xsl:text>
  </xsl:template>

  <xsl:template match="take">
    <div id="take">
     <div style="float: right;">
      <xsl:call-template name="command_anchor">
       <xsl:with-param name="text">
        <xsl:call-template name="kLoadTake"/>
       </xsl:with-param>
       <xsl:with-param name="command">open</xsl:with-param>
       <xsl:with-param name="argument">this_uri()</xsl:with-param>
       <xsl:with-param name="help">
        <xsl:call-template name="kLoadTakeTitle"/>
       </xsl:with-param>
       <xsl:with-param name="accesskey">L</xsl:with-param>
      </xsl:call-template>
      <xsl:text> , </xsl:text>
      <xsl:call-template name="command_anchor">
       <xsl:with-param name="text">
        <xsl:call-template name="kLoadTakeSource"/>
       </xsl:with-param>
       <xsl:with-param name="command">load_take_source</xsl:with-param>
       <xsl:with-param name="argument">this_uri()</xsl:with-param>
       <xsl:with-param name="help">
        <xsl:call-template name="kLoadTakeSourceTitle"/>
       </xsl:with-param>
       <xsl:with-param name="accesskey">S</xsl:with-param>
      </xsl:call-template>
      <xsl:if test="//channel_list/item/second/id[starts-with(., 'Hips')]">
       <xsl:text> , </xsl:text>
       <xsl:call-template name="command_anchor">
        <xsl:with-param name="text">
         <xsl:call-template name="kTrackTake"/>
        </xsl:with-param>
        <xsl:with-param name="command">track_take</xsl:with-param>
        <xsl:with-param name="argument">this_uri()</xsl:with-param>
        <xsl:with-param name="help">
         <xsl:call-template name="kTrackTakeTitle"/>
        </xsl:with-param>
        <xsl:with-param name="accesskey">T</xsl:with-param>
       </xsl:call-template>
      </xsl:if>
     </div>

     <!--
     <xsl:element name="video">
      <xsl:attribute name="src">
       <xsl:value-of select="video_path"/>
      </xsl:attribute>
      <xsl:attribute name="controls">
       <xsl:text>1</xsl:text>
      </xsl:attribute>
     </xsl:element>
     -->
     
     <h1>
      <xsl:call-template name="Title"/>
     </h1>
     <table>
        <tr>
          <th>Name</th>
          <td>
            <xsl:value-of select="name"/>
          </td>
        </tr>
        <tr>
          <th>Description</th>
          <td>
            <xsl:value-of select="description"/>
          </td>
        </tr>
        <tr>
          <th>Start time</th>
          <td>
            <xsl:apply-templates select="start"/>
          </td>
        </tr>
        <tr>
          <th>End time</th>
          <td>
            <xsl:apply-templates select="end"/>
          </td>
        </tr>
        <tr>
          <th>Location</th>
          <td>
            <xsl:apply-templates select="location"/>
          </td>
        </tr>
        <tr>
          <th>Geomagnetic</th>
          <td>
            <xsl:apply-templates select="geomagnetic"/>
          </td>
        </tr>
        <xsl:if test="string-length(video_path)">
        <tr>
         <th>Reference Video</th>
         <td>
          <xsl:element name="a">
           <xsl:attribute name="title">
            <xsl:text>View reference video associated with this take.</xsl:text>
           </xsl:attribute>
           <xsl:attribute name="href">
            <xsl:value-of select="video_path"/>
           </xsl:attribute>
           <xsl:value-of select="video_path"/>
          </xsl:element>
         </td>
        </tr>
        </xsl:if>
        <tr>
          <th>Configuration</th>
          <td>
            <xsl:element name="a">
              <xsl:attribute name="title">
                <xsl:text>View configuration file associated with this take.</xsl:text>
              </xsl:attribute>
              <xsl:attribute name="href">
                <xsl:value-of select="configuration_path"/>
              </xsl:attribute>
              <xsl:value-of select="configuration_path"/>
            </xsl:element>
          </td>
        </tr>
        <tr>
          <th>Channel list</th>
          <td>
            <xsl:apply-templates select="channel_list"/>
          </td>
        </tr>
      </table>
    </div>

  </xsl:template>

  <xsl:template match="start|end">
    <xsl:call-template name="format_iso_extended">
      <xsl:with-param name="value">
        <xsl:apply-templates/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="take/channel_list">
    <div id="configuration">
      <table>
        <thead>
          <tr>
            <th>Id</th>
            <th>Name</th>
            <th>Source</th>
          </tr>
        </thead>
        <tbody>
          <xsl:apply-templates select="item/second"/>
        </tbody>
      </table>
    </div>
  </xsl:template>

  <xsl:template match="take/channel_list/item/second">
    <tr>
      <td>
        <xsl:value-of select="id"/>
      </td>
      <td>
        <xsl:value-of select="name"/>
      </td>
      <td>
        <xsl:value-of select="source"/>
      </td>
    </tr>
  </xsl:template>

  <!-- Override default rules for real valued numbers. Use a common output format.  -->
  <xsl:template match="location|geomagnetic">
    <span class="item">
      <xsl:call-template name="real_format">
        <xsl:with-param name="text">
          <xsl:value-of select="substring-before(text(), ' ')"/>
        </xsl:with-param>
      </xsl:call-template>
    </span>
    <span class="item">
      <xsl:call-template name="real_format">
        <xsl:with-param name="text">
          <xsl:value-of select="substring-before(substring-after(text(), ' '), ' ')"/>
        </xsl:with-param>
      </xsl:call-template>
    </span>
    <span class="item">     
      <xsl:call-template name="real_format">
        <xsl:with-param name="text">
          <xsl:value-of select="substring-after(substring-after(text(), ' '), ' ')"/>
        </xsl:with-param>
      </xsl:call-template> 
    </span>
  </xsl:template>

  <xsl:template match="user_channel">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template name="real_format">
    <xsl:param name="text">0</xsl:param>
    <xsl:value-of select="format-number($text,'0.##')"/>
  </xsl:template>

</xsl:stylesheet>