/**
  @file    MotionCAPI.h
  @version 2.5

  Copyright (c) 2017, Motion Workshop
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice,
  this list of conditions and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __MNCAPI_H_
#define __MNCAPI_H_

#if !defined(MNCAPI_IMPORT_API)
#  if defined(_WIN32)
#    define MNCAPI_IMPORT_API __declspec(dllimport)
#  else
#    define MNCAPI_IMPORT_API
#  endif /* _WIN32 */
#endif /* MNCAPI_IMPORT_API */

#if !defined(MNCAPI_CALL_API)
#  if defined(_WIN32)
#    define MNCAPI_CALL_API __cdecl
#  else
#    define MNCAPI_CALL_API
#  endif /* _WIN32 */
#endif /* MNCAPI_CALL_API */

#ifdef __cplusplus
extern "C" {
#endif

#define MNCAPI_PREVIEW_SIZE (14)
#define MNCAPI_SENSOR_SIZE   (9)
#define MNCAPI_RAW_SIZE      (9)

enum mncapi_error_t {
  MNCAPI_FAILURE =  0,
  MNCAPI_SUCCESS =  1
};

enum mncapi_stream_t {
  MNCAPI_PREVIEW =  1,
  MNCAPI_SENSOR  =  2,
  MNCAPI_RAW     =  3
};

enum mncapi_blocking_t {
  MNCAPI_NOBLOCK = -1,
  MNCAPI_FOREVER =  0,
  MNCAPI_DEFAULT =  1
};

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_open(enum mncapi_stream_t type);

MNCAPI_IMPORT_API
void MNCAPI_CALL_API
mncapi_close(int handle);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_set_blocking(int handle,
                    int second);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_sample(int handle,
              float *data,
              int data_size);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_sample_int16(int handle,
                    short *data,
                    int data_size);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_get_preview(float *data);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_get_sensor(float *data);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_get_raw(short *data);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_open_host(enum mncapi_stream_t type,
                 const char *host,
                 int port);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_open_configurable(const char *xml,
                         const char *host,
                         int port);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_lua_chunk(const char *input,
                 char *output,
                 int output_size);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_lua_chunk_host(const char *host,
                      const char *input,
                      char *output,
                      int output_size);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_set_buffered(int handle,
                    int num);

MNCAPI_IMPORT_API
int MNCAPI_CALL_API
mncapi_sample_ready(int handle);

#ifdef __cplusplus
}
#endif

#endif /* __MNCAPI_H_ */
